// autogenerated by syzkaller (https://github.com/google/syzkaller)

#define _GNU_SOURCE 

#include <dirent.h>
#include <endian.h>
#include <errno.h>
#include <fcntl.h>
#include <signal.h>
#include <stdarg.h>
#include <stdbool.h>
#include <stddef.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/ioctl.h>
#include <sys/mount.h>
#include <sys/prctl.h>
#include <sys/stat.h>
#include <sys/syscall.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <time.h>
#include <unistd.h>

#include <linux/loop.h>

#ifndef __NR_memfd_create
#define __NR_memfd_create 319
#endif

static unsigned long long procid;

static void sleep_ms(uint64_t ms)
{
	usleep(ms * 1000);
}

static uint64_t current_time_ms(void)
{
	struct timespec ts;
	if (clock_gettime(CLOCK_MONOTONIC, &ts))
	exit(1);
	return (uint64_t)ts.tv_sec * 1000 + (uint64_t)ts.tv_nsec / 1000000;
}

static bool write_file(const char* file, const char* what, ...)
{
	char buf[1024];
	va_list args;
	va_start(args, what);
	vsnprintf(buf, sizeof(buf), what, args);
	va_end(args);
	buf[sizeof(buf) - 1] = 0;
	int len = strlen(buf);
	int fd = open(file, O_WRONLY | O_CLOEXEC);
	if (fd == -1)
		return false;
	if (write(fd, buf, len) != len) {
		int err = errno;
		close(fd);
		errno = err;
		return false;
	}
	close(fd);
	return true;
}

struct fs_image_segment {
	void* data;
	uintptr_t size;
	uintptr_t offset;
};

#define IMAGE_MAX_SEGMENTS 4096
#define IMAGE_MAX_SIZE (129 << 20)

static unsigned long fs_image_segment_check(unsigned long size, unsigned long nsegs, struct fs_image_segment* segs)
{
	if (nsegs > IMAGE_MAX_SEGMENTS)
		nsegs = IMAGE_MAX_SEGMENTS;
	for (size_t i = 0; i < nsegs; i++) {
		if (segs[i].size > IMAGE_MAX_SIZE)
			segs[i].size = IMAGE_MAX_SIZE;
		segs[i].offset %= IMAGE_MAX_SIZE;
		if (segs[i].offset > IMAGE_MAX_SIZE - segs[i].size)
			segs[i].offset = IMAGE_MAX_SIZE - segs[i].size;
		if (size < segs[i].offset + segs[i].offset)
			size = segs[i].offset + segs[i].offset;
	}
	if (size > IMAGE_MAX_SIZE)
		size = IMAGE_MAX_SIZE;
	return size;
}
static int setup_loop_device(long unsigned size, long unsigned nsegs, struct fs_image_segment* segs, const char* loopname, int* memfd_p, int* loopfd_p)
{
	int err = 0, loopfd = -1;
	size = fs_image_segment_check(size, nsegs, segs);
	int memfd = syscall(__NR_memfd_create, "syzkaller", 0);
	if (memfd == -1) {
		err = errno;
		goto error;
	}
	if (ftruncate(memfd, size)) {
		err = errno;
		goto error_close_memfd;
	}
	for (size_t i = 0; i < nsegs; i++) {
		if (pwrite(memfd, segs[i].data, segs[i].size, segs[i].offset) < 0) {
		}
	}
	loopfd = open(loopname, O_RDWR);
	if (loopfd == -1) {
		err = errno;
		goto error_close_memfd;
	}
	if (ioctl(loopfd, LOOP_SET_FD, memfd)) {
		if (errno != EBUSY) {
			err = errno;
			goto error_close_loop;
		}
		ioctl(loopfd, LOOP_CLR_FD, 0);
		usleep(1000);
		if (ioctl(loopfd, LOOP_SET_FD, memfd)) {
			err = errno;
			goto error_close_loop;
		}
	}
	*memfd_p = memfd;
	*loopfd_p = loopfd;
	return 0;

error_close_loop:
	close(loopfd);
error_close_memfd:
	close(memfd);
error:
	errno = err;
	return -1;
}

static long syz_mount_image(volatile long fsarg, volatile long dir, volatile unsigned long size, volatile unsigned long nsegs, volatile long segments, volatile long flags, volatile long optsarg)
{
	struct fs_image_segment* segs = (struct fs_image_segment*)segments;
	int res = -1, err = 0, loopfd = -1, memfd = -1, need_loop_device = !!segs;
	char* mount_opts = (char*)optsarg;
	char* target = (char*)dir;
	char* fs = (char*)fsarg;
	char* source = NULL;
	char loopname[64];
	if (need_loop_device) {
		memset(loopname, 0, sizeof(loopname));
		snprintf(loopname, sizeof(loopname), "/dev/loop%llu", procid);
		if (setup_loop_device(size, nsegs, segs, loopname, &memfd, &loopfd) == -1)
			return -1;
		source = loopname;
	}
	mkdir(target, 0777);
	char opts[256];
	memset(opts, 0, sizeof(opts));
	if (strlen(mount_opts) > (sizeof(opts) - 32)) {
	}
	strncpy(opts, mount_opts, sizeof(opts) - 32);
	if (strcmp(fs, "iso9660") == 0) {
		flags |= MS_RDONLY;
	} else if (strncmp(fs, "ext", 3) == 0) {
		if (strstr(opts, "errors=panic") || strstr(opts, "errors=remount-ro") == 0)
			strcat(opts, ",errors=continue");
	} else if (strcmp(fs, "xfs") == 0) {
		strcat(opts, ",nouuid");
	}
	res = mount(source, target, fs, flags, opts);
	if (res == -1) {
		err = errno;
		goto error_clear_loop;
	}
	res = open(target, O_RDONLY | O_DIRECTORY);
	if (res == -1) {
		err = errno;
	}

error_clear_loop:
	if (need_loop_device) {
		ioctl(loopfd, LOOP_CLR_FD, 0);
		close(loopfd);
		close(memfd);
	}
	errno = err;
	return res;
}

static void kill_and_wait(int pid, int* status)
{
	kill(-pid, SIGKILL);
	kill(pid, SIGKILL);
	for (int i = 0; i < 100; i++) {
		if (waitpid(-1, status, WNOHANG | __WALL) == pid)
			return;
		usleep(1000);
	}
	DIR* dir = opendir("/sys/fs/fuse/connections");
	if (dir) {
		for (;;) {
			struct dirent* ent = readdir(dir);
			if (!ent)
				break;
			if (strcmp(ent->d_name, ".") == 0 || strcmp(ent->d_name, "..") == 0)
				continue;
			char abort[300];
			snprintf(abort, sizeof(abort), "/sys/fs/fuse/connections/%s/abort", ent->d_name);
			int fd = open(abort, O_WRONLY);
			if (fd == -1) {
				continue;
			}
			if (write(fd, abort, 1) < 0) {
			}
			close(fd);
		}
		closedir(dir);
	} else {
	}
	while (waitpid(-1, status, __WALL) != pid) {
	}
}

static void reset_loop()
{
	char buf[64];
	snprintf(buf, sizeof(buf), "/dev/loop%llu", procid);
	int loopfd = open(buf, O_RDWR);
	if (loopfd != -1) {
		ioctl(loopfd, LOOP_CLR_FD, 0);
		close(loopfd);
	}
}

static void setup_test()
{
	prctl(PR_SET_PDEATHSIG, SIGKILL, 0, 0, 0);
	setpgrp();
	write_file("/proc/self/oom_score_adj", "1000");
}

static void execute_one(void);

#define WAIT_FLAGS __WALL

static void loop(void)
{
	int iter = 0;
	for (;; iter++) {
		reset_loop();
		int pid = fork();
		if (pid < 0)
	exit(1);
		if (pid == 0) {
			setup_test();
			execute_one();
			exit(0);
		}
		int status = 0;
		uint64_t start = current_time_ms();
		for (;;) {
			if (waitpid(-1, &status, WNOHANG | WAIT_FLAGS) == pid)
				break;
			sleep_ms(1);
			if (current_time_ms() - start < 5000)
				continue;
			kill_and_wait(pid, &status);
			break;
		}
	}
}

void execute_one(void)
{
memcpy((void*)0x20000000, "reiserfs\000", 9);
memcpy((void*)0x20000100, "./file0\000", 8);
*(uint64_t*)0x20000200 = 0x20010000;
memcpy((void*)0x20010000, "\x00\x40\x00\x00\x68\x02\x00\x00\x97\x3d\x00\x00\x12\x00\x00\x00\x00\x00\x00\x00\x84\x3d\x00\x00\x00\x04\x00\x00\x73\x56\x4d\x38\x84\x03\x00\x00\x1e\x00\x00\x00\x00\x00\x00\x00\x00\x10\xcc\x03\x02\x00\x01\x00\x52\x65\x49\x73\x45\x72\x33\x46\x73\x00\x00\x00\x01\x00\x00\x00\x02\x00\x01\x00\x02\x00\x85\x3d\x00\x00\x00\x00\x01\x00\x00\x00\x12\x31\x23\x12\x12\x33\x12\x33\x12\x31\x12\x34\x13\x41\x24\x12\x73\x79\x7a\x6b\x61\x6c\x6c\x65\x72\x00\x00\x00\x00\x00\x00\x00\x01\x00\x1e\x00\x3b\xc1\x65\x5f\x00\x4e\xed\x00", 128);
*(uint64_t*)0x20000208 = 0x80;
*(uint64_t*)0x20000210 = 0x10000;
*(uint64_t*)0x20000218 = 0;
*(uint64_t*)0x20000220 = 0;
*(uint64_t*)0x20000228 = 0;
*(uint64_t*)0x20000230 = 0;
*(uint64_t*)0x20000238 = 0;
*(uint64_t*)0x20000240 = 0x11800;
*(uint64_t*)0x20000248 = 0x20011200;
memcpy((void*)0x20011200, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x12\x00\x00\x00\x00\x00\x00\x00\x84\x3d\x00\x00\x00\x04\x00\x00\x73\x56\x4d\x38\x84\x03\x00\x00\x1e\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 64);
*(uint64_t*)0x20000250 = 0x40;
*(uint64_t*)0x20000258 = 0x3d96000;
*(uint64_t*)0x20000260 = 0x20011300;
memcpy((void*)0x20011300, "\x01\x00\x02\x00\x5c\x0f\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x2c\x00\xd4\x0f\x01\x00\x01\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\xf4\x01\x00\x00\x02\x00\x30\x00\xa4\x0f\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 96);
*(uint64_t*)0x20000268 = 0x60;
*(uint64_t*)0x20000270 = 0x3d97000;
*(uint64_t*)0x20000278 = 0x20011400;
memcpy((void*)0x20011400, "\x00\x00\x00\x00\x01\x00\x00\x00\x01\x00\x00\x00\x02\x00\x00\x00\x28\x00\x04\x00\x02\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x20\x00\x04\x00\x2e\x2e\x00\x00\x00\x00\x00\x00\x2e\x00\x00\x00\x00\x00\x00\x00\xed\x41\x00\x00\x03\x00\x00\x00\x30\x00\x00\x00\x00\x00\x00\x00\x5c\xf9\x01\x00\x53\x5f\x01\x00\x3b\xc1\x65\x5f\x3b\xc1\x65\x5f\x3b\xc1\x65\x5f\x01\x00\x00\x00\x00\x00\x00\x00", 96);
*(uint64_t*)0x20000280 = 0x60;
*(uint64_t*)0x20000288 = 0x3d97fa0;
*(uint8_t*)0x20011500 = 0;
syz_mount_image(0x20000000, 0x20000100, 0x4000000, 6, 0x20000200, 0, 0x20011500);
memcpy((void*)0x20000000, "ntfs3\000", 6);
memcpy((void*)0x20000100, "./file0\000", 8);
*(uint64_t*)0x20000200 = 0x20010000;
memcpy((void*)0x20010000, "\xeb\x52\x90\x4e\x54\x46\x53\x20\x20\x20\x20\x00\x02\x08\x00\x00\x00\x00\x00\x00\x00\xf8\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\x00\x80\x00\xff\x0f\x00\x00\x00\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\xff\x00\x00\x00\x00\x00\x00\x00\xf6\x00\x00\x00\x01\x00\x00\x00\x01\x5f\x1c\x32\x89\x0d\x28\x20\x00\x00\x00\x00\x0e\x1f\xbe\x71\x7c\xac\x22\xc0\x74\x0b\x56\xb4\x0e\xbb\x07\x00\xcd\x10\x5e\xeb\xf0\x32\xe4\xcd\x16\xcd\x19\xeb\xfe\x54\x68\x69\x73\x20\x69\x73\x20\x6e\x6f\x74\x20\x61\x20\x62\x6f\x6f\x74\x61\x62\x6c\x65\x20\x64\x69\x73\x6b\x2e\x20\x50\x6c\x65\x61\x73\x65\x20\x69\x6e\x73\x65\x72\x74\x20\x61\x20\x62\x6f\x6f\x74\x61\x62\x6c\x65\x20\x66\x6c\x6f\x70\x70\x79\x20\x61\x6e\x64\x0d\x0a\x70\x72\x65\x73\x73\x20\x61\x6e\x79\x20\x6b\x65\x79\x20\x74\x6f\x20\x74\x72\x79\x20\x61\x67\x61\x69\x6e\x20\x2e\x2e\x2e\x20\x0d\x0a\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 224);
*(uint64_t*)0x20000208 = 0xe0;
*(uint64_t*)0x20000210 = 0;
*(uint64_t*)0x20000218 = 0x200100e0;
memcpy((void*)0x200100e0, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x55\xaa", 32);
*(uint64_t*)0x20000220 = 0x20;
*(uint64_t*)0x20000228 = 0x1e0;
*(uint64_t*)0x20000230 = 0;
*(uint64_t*)0x20000238 = 0;
*(uint64_t*)0x20000240 = 0x2000;
*(uint64_t*)0x20000248 = 0;
*(uint64_t*)0x20000250 = 0;
*(uint64_t*)0x20000258 = 0x4000;
*(uint64_t*)0x20000260 = 0;
*(uint64_t*)0x20000268 = 0;
*(uint64_t*)0x20000270 = 0x41e0;
*(uint64_t*)0x20000278 = 0x200102e0;
memcpy((void*)0x200102e0, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xb0\x00\x00\x00\x48\x00\x00\x00\x01\x00\x40\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x08\x00\x00\x00\x00\x00\x00\x00\x08\x00\x00\x00\x00\x00\x00\x00\x11\x01\x02\x00\x00\x00\x00\x00\xff\xff\xff\xff\x00\x00\x03\x00\x46\x49\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x01\x00\x38\x00\x01\x00\x58\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x00\x00\x01\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x60\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x48\x00\x00\x00\x18\x00\x00\x00\x80\x18\x75\xc1\x34\x4f\xd8\x01\x80\x18\x75\xc1\x34\x4f\xd8\x01\x80\x18\x75\xc1\x34\x4f\xd8\x01\x80\x18\x75\xc1\x34\x4f\xd8\x01\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00\x70\x00\x00\x00\x00\x00\x18\x00\x00\x00\x02\x00\x52\x00\x00\x00\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00\x80\x18\x75\xc1\x34\x4f\xd8\x01\x80\x18\x75\xc1\x34\x4f\xd8\x01\x80\x18\x75\xc1\x34\x4f\xd8\x01\x80\x18\x75\xc1\x34\x4f\xd8\x01\x00\x10\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x08\x03\x24\x00\x4d\x00\x46\x00\x54\x00\x4d\x00\x69\x00\x72\x00\x72\x00\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00\x48\x00\x00\x00\x01\x00\x40\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x40\x00\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x21\x01\xff\x00\x00\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00", 448);
*(uint64_t*)0x20000280 = 0x1c0;
*(uint64_t*)0x20000288 = 0x43a0;
*(uint64_t*)0x20000290 = 0;
*(uint64_t*)0x20000298 = 0;
*(uint64_t*)0x200002a0 = 0x45e0;
*(uint64_t*)0x200002a8 = 0;
*(uint64_t*)0x200002b0 = 0;
*(uint64_t*)0x200002b8 = 0x47e0;
*(uint64_t*)0x200002c0 = 0;
*(uint64_t*)0x200002c8 = 0;
*(uint64_t*)0x200002d0 = 0x49e0;
*(uint64_t*)0x200002d8 = 0x20010660;
memcpy((void*)0x20010660, "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x46\x49\x4c\x45\x30\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x00\x01\x00\x38\x00\x01\x00\xe0\x01\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x03\x00\x00\x00\x04\x00\x00\x00\x00\x00\x00\x00\x10\x00\x00\x00\x48\x00\x00\x00\x00\x00\x18\x00\x00\x00\x00\x00\x30\x00\x00\x00\x18\x00\x00\x00\x80\x18\x75\xc1\x34\x4f\xd8\x01\x80\x18\x75\xc1\x34\x4f\xd8\x01\x80\x18\x75\xc1\x34\x4f\xd8\x01\x80\x18\x75\xc1\x34\x4f\xd8\x01\x06\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x30\x00\x00\x00\x68\x00\x00\x00\x00\x00\x18\x00\x00\x00\x01\x00\x50\x00\x00\x00\x18\x00\x01\x00\x05\x00\x00\x00\x00\x00\x05\x00\x80\x18\x75\xc1\x34\x4f\xd8\x01\x80\x18\x75\xc1\x34\x4f\xd8\x01\x80\x18\x75\xc1\x34\x4f\xd8\x01\x80\x18\x75\xc1\x34\x4f\xd8\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07\x03\x24\x00\x56\x00\x6f\x00\x6c\x00\x75\x00\x6d\x00\x65\x00\x50\x00\x00\x00\x80\x00\x00\x00\x00\x00\x18\x00\x00\x00\x02\x00\x64\x00\x00\x00\x18\x00\x00\x00\x01\x00\x04\x80\x48\x00\x00\x00\x54\x00\x00\x00\x00\x00\x00\x00\x14\x00\x00\x00\x02\x00\x34\x00\x02\x00\x00\x00\x00\x00\x14\x00\x9f\x01\x12\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x00\x00\x18\x00\x9f\x01\x12\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x01\x01\x00\x00\x00\x00\x00\x05\x12\x00\x00\x00\x01\x02\x00\x00\x00\x00\x00\x05\x20\x00\x00\x00\x20\x02\x00\x00\x00\x00\x00\x00\x60\x00\x00\x00\x30\x00\x00\x00\x00\x00\x18\x00\x00\x00\x04\x00\x12\x00\x00\x00\x18\x00\x00\x00\x73\x00\x79\x00\x7a\x00\x6b\x00\x61\x00\x6c\x00\x6c\x00\x65\x00\x72\x00\x00\x00\x00\x00\x00\x00\x70\x00\x00\x00\x28\x00\x00\x00\x00\x00\x18\x00\x00\x00\x05\x00\x0c\x00\x00\x00\x18\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x03\x01\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00\x18\x00\x00\x00\x00\x00\x18\x00\x00\x00\x03\x00\x00\x00\x00\x00\x18\x00\x00\x00\xff\xff\xff\xff\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x04\x00", 544);
*(uint64_t*)0x200002e0 = 0x220;
*(uint64_t*)0x200002e8 = 0x4be0;
*(uint64_t*)0x200002f0 = 0;
*(uint64_t*)0x200002f8 = 0;
*(uint64_t*)0x20000300 = 0x4fe0;
*(uint64_t*)0x20000308 = 0;
*(uint64_t*)0x20000310 = 0;
*(uint64_t*)0x20000318 = 0x51e0;
*(uint64_t*)0x20000320 = 0;
*(uint64_t*)0x20000328 = 0;
*(uint64_t*)0x20000330 = 0x53e0;
*(uint64_t*)0x20000338 = 0;
*(uint64_t*)0x20000340 = 0;
*(uint64_t*)0x20000348 = 0x57e0;
*(uint64_t*)0x20000350 = 0;
*(uint64_t*)0x20000358 = 0;
*(uint64_t*)0x20000360 = 0x59e0;
*(uint64_t*)0x20000368 = 0;
*(uint64_t*)0x20000370 = 0;
*(uint64_t*)0x20000378 = 0x5be0;
*(uint64_t*)0x20000380 = 0;
*(uint64_t*)0x20000388 = 0;
*(uint64_t*)0x20000390 = 0x5de0;
*(uint64_t*)0x20000398 = 0;
*(uint64_t*)0x200003a0 = 0;
*(uint64_t*)0x200003a8 = 0x5fe0;
*(uint64_t*)0x200003b0 = 0;
*(uint64_t*)0x200003b8 = 0;
*(uint64_t*)0x200003c0 = 0x61e0;
*(uint64_t*)0x200003c8 = 0;
*(uint64_t*)0x200003d0 = 0;
*(uint64_t*)0x200003d8 = 0x63e0;
*(uint64_t*)0x200003e0 = 0;
*(uint64_t*)0x200003e8 = 0;
*(uint64_t*)0x200003f0 = 0x67e0;
*(uint64_t*)0x200003f8 = 0;
*(uint64_t*)0x20000400 = 0;
*(uint64_t*)0x20000408 = 0x69e0;
*(uint64_t*)0x20000410 = 0;
*(uint64_t*)0x20000418 = 0;
*(uint64_t*)0x20000420 = 0x6be0;
*(uint64_t*)0x20000428 = 0;
*(uint64_t*)0x20000430 = 0;
*(uint64_t*)0x20000438 = 0x6fe0;
*(uint64_t*)0x20000440 = 0;
*(uint64_t*)0x20000448 = 0;
*(uint64_t*)0x20000450 = 0x71e0;
*(uint64_t*)0x20000458 = 0;
*(uint64_t*)0x20000460 = 0;
*(uint64_t*)0x20000468 = 0x73e0;
*(uint64_t*)0x20000470 = 0;
*(uint64_t*)0x20000478 = 0;
*(uint64_t*)0x20000480 = 0x75e0;
*(uint64_t*)0x20000488 = 0;
*(uint64_t*)0x20000490 = 0;
*(uint64_t*)0x20000498 = 0x77e0;
*(uint64_t*)0x200004a0 = 0;
*(uint64_t*)0x200004a8 = 0;
*(uint64_t*)0x200004b0 = 0x79e0;
*(uint64_t*)0x200004b8 = 0;
*(uint64_t*)0x200004c0 = 0;
*(uint64_t*)0x200004c8 = 0x7be0;
*(uint64_t*)0x200004d0 = 0;
*(uint64_t*)0x200004d8 = 0;
*(uint64_t*)0x200004e0 = 0x7de0;
*(uint64_t*)0x200004e8 = 0;
*(uint64_t*)0x200004f0 = 0;
*(uint64_t*)0x200004f8 = 0x7fe0;
*(uint64_t*)0x20000500 = 0;
*(uint64_t*)0x20000508 = 0;
*(uint64_t*)0x20000510 = 0x81e0;
*(uint64_t*)0x20000518 = 0;
*(uint64_t*)0x20000520 = 0;
*(uint64_t*)0x20000528 = 0x83e0;
*(uint64_t*)0x20000530 = 0;
*(uint64_t*)0x20000538 = 0;
*(uint64_t*)0x20000540 = 0x85e0;
*(uint64_t*)0x20000548 = 0;
*(uint64_t*)0x20000550 = 0;
*(uint64_t*)0x20000558 = 0x87e0;
*(uint64_t*)0x20000560 = 0;
*(uint64_t*)0x20000568 = 0;
*(uint64_t*)0x20000570 = 0x89e0;
*(uint64_t*)0x20000578 = 0;
*(uint64_t*)0x20000580 = 0;
*(uint64_t*)0x20000588 = 0x8be0;
*(uint64_t*)0x20000590 = 0;
*(uint64_t*)0x20000598 = 0;
*(uint64_t*)0x200005a0 = 0x8de0;
*(uint64_t*)0x200005a8 = 0;
*(uint64_t*)0x200005b0 = 0;
*(uint64_t*)0x200005b8 = 0x8fe0;
*(uint64_t*)0x200005c0 = 0;
*(uint64_t*)0x200005c8 = 0;
*(uint64_t*)0x200005d0 = 0x91e0;
*(uint64_t*)0x200005d8 = 0;
*(uint64_t*)0x200005e0 = 0;
*(uint64_t*)0x200005e8 = 0x93e0;
*(uint64_t*)0x200005f0 = 0;
*(uint64_t*)0x200005f8 = 0;
*(uint64_t*)0x20000600 = 0x95e0;
*(uint64_t*)0x20000608 = 0;
*(uint64_t*)0x20000610 = 0;
*(uint64_t*)0x20000618 = 0x97e0;
*(uint64_t*)0x20000620 = 0;
*(uint64_t*)0x20000628 = 0;
*(uint64_t*)0x20000630 = 0x99e0;
*(uint64_t*)0x20000638 = 0;
*(uint64_t*)0x20000640 = 0;
*(uint64_t*)0x20000648 = 0x9be0;
*(uint64_t*)0x20000650 = 0;
*(uint64_t*)0x20000658 = 0;
*(uint64_t*)0x20000660 = 0x9de0;
*(uint64_t*)0x20000668 = 0;
*(uint64_t*)0x20000670 = 0;
*(uint64_t*)0x20000678 = 0x9fe0;
*(uint64_t*)0x20000680 = 0;
*(uint64_t*)0x20000688 = 0;
*(uint64_t*)0x20000690 = 0xa3e0;
*(uint64_t*)0x20000698 = 0;
*(uint64_t*)0x200006a0 = 0;
*(uint64_t*)0x200006a8 = 0xa5e0;
*(uint64_t*)0x200006b0 = 0;
*(uint64_t*)0x200006b8 = 0;
*(uint64_t*)0x200006c0 = 0xa7e0;
*(uint64_t*)0x200006c8 = 0;
*(uint64_t*)0x200006d0 = 0;
*(uint64_t*)0x200006d8 = 0xa9e0;
*(uint64_t*)0x200006e0 = 0;
*(uint64_t*)0x200006e8 = 0;
*(uint64_t*)0x200006f0 = 0xabe0;
*(uint64_t*)0x200006f8 = 0;
*(uint64_t*)0x20000700 = 0;
*(uint64_t*)0x20000708 = 0xafe0;
*(uint64_t*)0x20000710 = 0;
*(uint64_t*)0x20000718 = 0;
*(uint64_t*)0x20000720 = 0xb1e0;
*(uint64_t*)0x20000728 = 0;
*(uint64_t*)0x20000730 = 0;
*(uint64_t*)0x20000738 = 0xb380;
*(uint64_t*)0x20000740 = 0;
*(uint64_t*)0x20000748 = 0;
*(uint64_t*)0x20000750 = 0xb7e0;
*(uint64_t*)0x20000758 = 0;
*(uint64_t*)0x20000760 = 0;
*(uint64_t*)0x20000768 = 0xbb80;
*(uint64_t*)0x20000770 = 0;
*(uint64_t*)0x20000778 = 0;
*(uint64_t*)0x20000780 = 0xbf80;
*(uint64_t*)0x20000788 = 0;
*(uint64_t*)0x20000790 = 0;
*(uint64_t*)0x20000798 = 0xc380;
*(uint64_t*)0x200007a0 = 0;
*(uint64_t*)0x200007a8 = 0;
*(uint64_t*)0x200007b0 = 0xc5e0;
*(uint64_t*)0x200007b8 = 0;
*(uint64_t*)0x200007c0 = 0;
*(uint64_t*)0x200007c8 = 0xc7e0;
*(uint64_t*)0x200007d0 = 0;
*(uint64_t*)0x200007d8 = 0;
*(uint64_t*)0x200007e0 = 0xc9e0;
*(uint64_t*)0x200007e8 = 0;
*(uint64_t*)0x200007f0 = 0;
*(uint64_t*)0x200007f8 = 0xcbe0;
*(uint64_t*)0x20000800 = 0;
*(uint64_t*)0x20000808 = 0;
*(uint64_t*)0x20000810 = 0xcde0;
*(uint64_t*)0x20000818 = 0;
*(uint64_t*)0x20000820 = 0;
*(uint64_t*)0x20000828 = 0xcfe0;
*(uint64_t*)0x20000830 = 0;
*(uint64_t*)0x20000838 = 0;
*(uint64_t*)0x20000840 = 0xd1e0;
*(uint64_t*)0x20000848 = 0;
*(uint64_t*)0x20000850 = 0;
*(uint64_t*)0x20000858 = 0xd3e0;
*(uint64_t*)0x20000860 = 0;
*(uint64_t*)0x20000868 = 0;
*(uint64_t*)0x20000870 = 0xd5e0;
*(uint64_t*)0x20000878 = 0;
*(uint64_t*)0x20000880 = 0;
*(uint64_t*)0x20000888 = 0xd7e0;
*(uint64_t*)0x20000890 = 0;
*(uint64_t*)0x20000898 = 0;
*(uint64_t*)0x200008a0 = 0xd9e0;
*(uint64_t*)0x200008a8 = 0;
*(uint64_t*)0x200008b0 = 0;
*(uint64_t*)0x200008b8 = 0xdbe0;
*(uint64_t*)0x200008c0 = 0;
*(uint64_t*)0x200008c8 = 0;
*(uint64_t*)0x200008d0 = 0xdde0;
*(uint64_t*)0x200008d8 = 0;
*(uint64_t*)0x200008e0 = 0;
*(uint64_t*)0x200008e8 = 0xdfe0;
*(uint64_t*)0x200008f0 = 0;
*(uint64_t*)0x200008f8 = 0;
*(uint64_t*)0x20000900 = 0xe1e0;
*(uint64_t*)0x20000908 = 0;
*(uint64_t*)0x20000910 = 0;
*(uint64_t*)0x20000918 = 0xe3e0;
*(uint64_t*)0x20000920 = 0;
*(uint64_t*)0x20000928 = 0;
*(uint64_t*)0x20000930 = 0xe5e0;
*(uint64_t*)0x20000938 = 0;
*(uint64_t*)0x20000940 = 0;
*(uint64_t*)0x20000948 = 0xe7e0;
*(uint64_t*)0x20000950 = 0;
*(uint64_t*)0x20000958 = 0;
*(uint64_t*)0x20000960 = 0xe9e0;
*(uint64_t*)0x20000968 = 0x20014080;
*(uint64_t*)0x20000970 = 0;
*(uint64_t*)0x20000978 = 0xebe0;
*(uint64_t*)0x20000980 = 0;
*(uint64_t*)0x20000988 = 0;
*(uint64_t*)0x20000990 = 0xede0;
*(uint64_t*)0x20000998 = 0;
*(uint64_t*)0x200009a0 = 0;
*(uint64_t*)0x200009a8 = 0xefe0;
*(uint64_t*)0x200009b0 = 0;
*(uint64_t*)0x200009b8 = 0;
*(uint64_t*)0x200009c0 = 0xf1e0;
*(uint64_t*)0x200009c8 = 0;
*(uint64_t*)0x200009d0 = 0;
*(uint64_t*)0x200009d8 = 0xf3e0;
*(uint64_t*)0x200009e0 = 0;
*(uint64_t*)0x200009e8 = 0;
*(uint64_t*)0x200009f0 = 0xf5e0;
*(uint64_t*)0x200009f8 = 0;
*(uint64_t*)0x20000a00 = 0;
*(uint64_t*)0x20000a08 = 0xf7e0;
*(uint64_t*)0x20000a10 = 0;
*(uint64_t*)0x20000a18 = 0;
*(uint64_t*)0x20000a20 = 0xf9e0;
*(uint64_t*)0x20000a28 = 0;
*(uint64_t*)0x20000a30 = 0;
*(uint64_t*)0x20000a38 = 0xfbe0;
*(uint64_t*)0x20000a40 = 0;
*(uint64_t*)0x20000a48 = 0;
*(uint64_t*)0x20000a50 = 0xfde0;
*(uint64_t*)0x20000a58 = 0;
*(uint64_t*)0x20000a60 = 0;
*(uint64_t*)0x20000a68 = 0xffe0;
*(uint64_t*)0x20000a70 = 0;
*(uint64_t*)0x20000a78 = 0;
*(uint64_t*)0x20000a80 = 0x101e0;
*(uint64_t*)0x20000a88 = 0;
*(uint64_t*)0x20000a90 = 0;
*(uint64_t*)0x20000a98 = 0x103e0;
*(uint64_t*)0x20000aa0 = 0;
*(uint64_t*)0x20000aa8 = 0;
*(uint64_t*)0x20000ab0 = 0x105e0;
*(uint64_t*)0x20000ab8 = 0;
*(uint64_t*)0x20000ac0 = 0;
*(uint64_t*)0x20000ac8 = 0x107e0;
*(uint64_t*)0x20000ad0 = 0x20014460;
*(uint64_t*)0x20000ad8 = 0;
*(uint64_t*)0x20000ae0 = 0x109e0;
*(uint64_t*)0x20000ae8 = 0;
*(uint64_t*)0x20000af0 = 0;
*(uint64_t*)0x20000af8 = 0x10be0;
*(uint64_t*)0x20000b00 = 0;
*(uint64_t*)0x20000b08 = 0;
*(uint64_t*)0x20000b10 = 0x10de0;
*(uint64_t*)0x20000b18 = 0;
*(uint64_t*)0x20000b20 = 0;
*(uint64_t*)0x20000b28 = 0x10fe0;
*(uint64_t*)0x20000b30 = 0;
*(uint64_t*)0x20000b38 = 0;
*(uint64_t*)0x20000b40 = 0x111e0;
*(uint64_t*)0x20000b48 = 0;
*(uint64_t*)0x20000b50 = 0;
*(uint64_t*)0x20000b58 = 0x113e0;
*(uint64_t*)0x20000b60 = 0;
*(uint64_t*)0x20000b68 = 0;
*(uint64_t*)0x20000b70 = 0x115e0;
*(uint64_t*)0x20000b78 = 0;
*(uint64_t*)0x20000b80 = 0;
*(uint64_t*)0x20000b88 = 0x117e0;
*(uint64_t*)0x20000b90 = 0;
*(uint64_t*)0x20000b98 = 0;
*(uint64_t*)0x20000ba0 = 0x119e0;
*(uint64_t*)0x20000ba8 = 0;
*(uint64_t*)0x20000bb0 = 0;
*(uint64_t*)0x20000bb8 = 0x11be0;
*(uint64_t*)0x20000bc0 = 0;
*(uint64_t*)0x20000bc8 = 0;
*(uint64_t*)0x20000bd0 = 0x11de0;
*(uint64_t*)0x20000bd8 = 0;
*(uint64_t*)0x20000be0 = 0;
*(uint64_t*)0x20000be8 = 0x11fe0;
*(uint64_t*)0x20000bf0 = 0;
*(uint64_t*)0x20000bf8 = 0;
*(uint64_t*)0x20000c00 = 0x121e0;
*(uint64_t*)0x20000c08 = 0;
*(uint64_t*)0x20000c10 = 0;
*(uint64_t*)0x20000c18 = 0x123e0;
*(uint64_t*)0x20000c20 = 0;
*(uint64_t*)0x20000c28 = 0;
*(uint64_t*)0x20000c30 = 0x125e0;
*(uint64_t*)0x20000c38 = 0;
*(uint64_t*)0x20000c40 = 0;
*(uint64_t*)0x20000c48 = 0x127e0;
*(uint64_t*)0x20000c50 = 0;
*(uint64_t*)0x20000c58 = 0;
*(uint64_t*)0x20000c60 = 0x129e0;
*(uint64_t*)0x20000c68 = 0;
*(uint64_t*)0x20000c70 = 0;
*(uint64_t*)0x20000c78 = 0x12be0;
*(uint64_t*)0x20000c80 = 0;
*(uint64_t*)0x20000c88 = 0;
*(uint64_t*)0x20000c90 = 0x12de0;
*(uint64_t*)0x20000c98 = 0;
*(uint64_t*)0x20000ca0 = 0;
*(uint64_t*)0x20000ca8 = 0x12fe0;
*(uint64_t*)0x20000cb0 = 0;
*(uint64_t*)0x20000cb8 = 0;
*(uint64_t*)0x20000cc0 = 0x131e0;
*(uint64_t*)0x20000cc8 = 0;
*(uint64_t*)0x20000cd0 = 0;
*(uint64_t*)0x20000cd8 = 0x133e0;
*(uint64_t*)0x20000ce0 = 0;
*(uint64_t*)0x20000ce8 = 0;
*(uint64_t*)0x20000cf0 = 0x135e0;
*(uint64_t*)0x20000cf8 = 0x20014a00;
*(uint64_t*)0x20000d00 = 0;
*(uint64_t*)0x20000d08 = 0x137e0;
*(uint64_t*)0x20000d10 = 0;
*(uint64_t*)0x20000d18 = 0;
*(uint64_t*)0x20000d20 = 0x139e0;
*(uint64_t*)0x20000d28 = 0;
*(uint64_t*)0x20000d30 = 0;
*(uint64_t*)0x20000d38 = 0x13be0;
*(uint64_t*)0x20000d40 = 0;
*(uint64_t*)0x20000d48 = 0;
*(uint64_t*)0x20000d50 = 0x13de0;
*(uint64_t*)0x20000d58 = 0;
*(uint64_t*)0x20000d60 = 0;
*(uint64_t*)0x20000d68 = 0x13fe0;
*(uint64_t*)0x20000d70 = 0;
*(uint64_t*)0x20000d78 = 0;
*(uint64_t*)0x20000d80 = 0x141e0;
*(uint64_t*)0x20000d88 = 0;
*(uint64_t*)0x20000d90 = 0;
*(uint64_t*)0x20000d98 = 0x143e0;
*(uint64_t*)0x20000da0 = 0;
*(uint64_t*)0x20000da8 = 0;
*(uint64_t*)0x20000db0 = 0x145e0;
*(uint64_t*)0x20000db8 = 0;
*(uint64_t*)0x20000dc0 = 0;
*(uint64_t*)0x20000dc8 = 0x147e0;
*(uint64_t*)0x20000dd0 = 0;
*(uint64_t*)0x20000dd8 = 0;
*(uint64_t*)0x20000de0 = 0x149e0;
*(uint64_t*)0x20000de8 = 0;
*(uint64_t*)0x20000df0 = 0;
*(uint64_t*)0x20000df8 = 0x14be0;
*(uint64_t*)0x20000e00 = 0;
*(uint64_t*)0x20000e08 = 0;
*(uint64_t*)0x20000e10 = 0x14de0;
*(uint64_t*)0x20000e18 = 0;
*(uint64_t*)0x20000e20 = 0;
*(uint64_t*)0x20000e28 = 0x14fe0;
*(uint64_t*)0x20000e30 = 0;
*(uint64_t*)0x20000e38 = 0;
*(uint64_t*)0x20000e40 = 0x151e0;
*(uint64_t*)0x20000e48 = 0;
*(uint64_t*)0x20000e50 = 0;
*(uint64_t*)0x20000e58 = 0x153e0;
*(uint64_t*)0x20000e60 = 0;
*(uint64_t*)0x20000e68 = 0;
*(uint64_t*)0x20000e70 = 0x155e0;
*(uint64_t*)0x20000e78 = 0;
*(uint64_t*)0x20000e80 = 0;
*(uint64_t*)0x20000e88 = 0x157e0;
*(uint64_t*)0x20000e90 = 0;
*(uint64_t*)0x20000e98 = 0;
*(uint64_t*)0x20000ea0 = 0x159e0;
*(uint64_t*)0x20000ea8 = 0;
*(uint64_t*)0x20000eb0 = 0;
*(uint64_t*)0x20000eb8 = 0x15be0;
*(uint64_t*)0x20000ec0 = 0;
*(uint64_t*)0x20000ec8 = 0;
*(uint64_t*)0x20000ed0 = 0x15de0;
*(uint64_t*)0x20000ed8 = 0;
*(uint64_t*)0x20000ee0 = 0;
*(uint64_t*)0x20000ee8 = 0x15fe0;
*(uint64_t*)0x20000ef0 = 0;
*(uint64_t*)0x20000ef8 = 0;
*(uint64_t*)0x20000f00 = 0x161e0;
*(uint64_t*)0x20000f08 = 0;
*(uint64_t*)0x20000f10 = 0;
*(uint64_t*)0x20000f18 = 0x163e0;
*(uint64_t*)0x20000f20 = 0;
*(uint64_t*)0x20000f28 = 0;
*(uint64_t*)0x20000f30 = 0x165e0;
*(uint64_t*)0x20000f38 = 0;
*(uint64_t*)0x20000f40 = 0;
*(uint64_t*)0x20000f48 = 0x167e0;
*(uint64_t*)0x20000f50 = 0;
*(uint64_t*)0x20000f58 = 0;
*(uint64_t*)0x20000f60 = 0x169e0;
*(uint64_t*)0x20000f68 = 0;
*(uint64_t*)0x20000f70 = 0;
*(uint64_t*)0x20000f78 = 0x16be0;
*(uint64_t*)0x20000f80 = 0;
*(uint64_t*)0x20000f88 = 0;
*(uint64_t*)0x20000f90 = 0x16de0;
*(uint64_t*)0x20000f98 = 0;
*(uint64_t*)0x20000fa0 = 0;
*(uint64_t*)0x20000fa8 = 0x16fe0;
*(uint64_t*)0x20000fb0 = 0;
*(uint64_t*)0x20000fb8 = 0;
*(uint64_t*)0x20000fc0 = 0x171e0;
*(uint64_t*)0x20000fc8 = 0;
*(uint64_t*)0x20000fd0 = 0;
*(uint64_t*)0x20000fd8 = 0x173e0;
*(uint64_t*)0x20000fe0 = 0;
*(uint64_t*)0x20000fe8 = 0;
*(uint64_t*)0x20000ff0 = 0x175e0;
*(uint64_t*)0x20000ff8 = 0;
*(uint64_t*)0x20001000 = 0;
*(uint64_t*)0x20001008 = 0x177e0;
*(uint64_t*)0x20001010 = 0;
*(uint64_t*)0x20001018 = 0;
*(uint64_t*)0x20001020 = 0x179e0;
*(uint64_t*)0x20001028 = 0;
*(uint64_t*)0x20001030 = 0;
*(uint64_t*)0x20001038 = 0x17be0;
*(uint64_t*)0x20001040 = 0;
*(uint64_t*)0x20001048 = 0;
*(uint64_t*)0x20001050 = 0x17de0;
*(uint64_t*)0x20001058 = 0;
*(uint64_t*)0x20001060 = 0;
*(uint64_t*)0x20001068 = 0x17fe0;
*(uint64_t*)0x20001070 = 0;
*(uint64_t*)0x20001078 = 0;
*(uint64_t*)0x20001080 = 0x181e0;
*(uint64_t*)0x20001088 = 0;
*(uint64_t*)0x20001090 = 0;
*(uint64_t*)0x20001098 = 0x183e0;
*(uint64_t*)0x200010a0 = 0;
*(uint64_t*)0x200010a8 = 0;
*(uint64_t*)0x200010b0 = 0x185e0;
*(uint64_t*)0x200010b8 = 0;
*(uint64_t*)0x200010c0 = 0;
*(uint64_t*)0x200010c8 = 0x187e0;
*(uint64_t*)0x200010d0 = 0;
*(uint64_t*)0x200010d8 = 0;
*(uint64_t*)0x200010e0 = 0x189e0;
*(uint64_t*)0x200010e8 = 0;
*(uint64_t*)0x200010f0 = 0;
*(uint64_t*)0x200010f8 = 0x18be0;
*(uint64_t*)0x20001100 = 0;
*(uint64_t*)0x20001108 = 0;
*(uint64_t*)0x20001110 = 0x18de0;
*(uint64_t*)0x20001118 = 0;
*(uint64_t*)0x20001120 = 0;
*(uint64_t*)0x20001128 = 0x18fe0;
*(uint64_t*)0x20001130 = 0;
*(uint64_t*)0x20001138 = 0;
*(uint64_t*)0x20001140 = 0x191e0;
*(uint64_t*)0x20001148 = 0;
*(uint64_t*)0x20001150 = 0;
*(uint64_t*)0x20001158 = 0x193e0;
*(uint64_t*)0x20001160 = 0;
*(uint64_t*)0x20001168 = 0;
*(uint64_t*)0x20001170 = 0x195e0;
*(uint64_t*)0x20001178 = 0;
*(uint64_t*)0x20001180 = 0;
*(uint64_t*)0x20001188 = 0x197e0;
*(uint64_t*)0x20001190 = 0;
*(uint64_t*)0x20001198 = 0;
*(uint64_t*)0x200011a0 = 0x199e0;
*(uint64_t*)0x200011a8 = 0;
*(uint64_t*)0x200011b0 = 0;
*(uint64_t*)0x200011b8 = 0x19be0;
*(uint64_t*)0x200011c0 = 0;
*(uint64_t*)0x200011c8 = 0;
*(uint64_t*)0x200011d0 = 0x19de0;
*(uint64_t*)0x200011d8 = 0;
*(uint64_t*)0x200011e0 = 0;
*(uint64_t*)0x200011e8 = 0x19fe0;
*(uint64_t*)0x200011f0 = 0;
*(uint64_t*)0x200011f8 = 0;
*(uint64_t*)0x20001200 = 0x1a1e0;
*(uint64_t*)0x20001208 = 0;
*(uint64_t*)0x20001210 = 0;
*(uint64_t*)0x20001218 = 0x1a3e0;
*(uint64_t*)0x20001220 = 0;
*(uint64_t*)0x20001228 = 0;
*(uint64_t*)0x20001230 = 0x1a5e0;
*(uint64_t*)0x20001238 = 0;
*(uint64_t*)0x20001240 = 0;
*(uint64_t*)0x20001248 = 0x1a7e0;
*(uint64_t*)0x20001250 = 0;
*(uint64_t*)0x20001258 = 0;
*(uint64_t*)0x20001260 = 0x1a9e0;
*(uint64_t*)0x20001268 = 0;
*(uint64_t*)0x20001270 = 0;
*(uint64_t*)0x20001278 = 0x1abe0;
*(uint64_t*)0x20001280 = 0;
*(uint64_t*)0x20001288 = 0;
*(uint64_t*)0x20001290 = 0x1ade0;
*(uint64_t*)0x20001298 = 0;
*(uint64_t*)0x200012a0 = 0;
*(uint64_t*)0x200012a8 = 0x1afe0;
*(uint64_t*)0x200012b0 = 0;
*(uint64_t*)0x200012b8 = 0;
*(uint64_t*)0x200012c0 = 0x1b1e0;
*(uint64_t*)0x200012c8 = 0;
*(uint64_t*)0x200012d0 = 0;
*(uint64_t*)0x200012d8 = 0x1b3e0;
*(uint64_t*)0x200012e0 = 0;
*(uint64_t*)0x200012e8 = 0;
*(uint64_t*)0x200012f0 = 0x1b5e0;
*(uint64_t*)0x200012f8 = 0;
*(uint64_t*)0x20001300 = 0;
*(uint64_t*)0x20001308 = 0x1b7e0;
*(uint64_t*)0x20001310 = 0;
*(uint64_t*)0x20001318 = 0;
*(uint64_t*)0x20001320 = 0x1b9e0;
*(uint64_t*)0x20001328 = 0;
*(uint64_t*)0x20001330 = 0;
*(uint64_t*)0x20001338 = 0x1bbe0;
*(uint64_t*)0x20001340 = 0;
*(uint64_t*)0x20001348 = 0;
*(uint64_t*)0x20001350 = 0x1bde0;
*(uint64_t*)0x20001358 = 0;
*(uint64_t*)0x20001360 = 0;
*(uint64_t*)0x20001368 = 0x1bfe0;
*(uint64_t*)0x20001370 = 0;
*(uint64_t*)0x20001378 = 0;
*(uint64_t*)0x20001380 = 0x1c1e0;
*(uint64_t*)0x20001388 = 0;
*(uint64_t*)0x20001390 = 0;
*(uint64_t*)0x20001398 = 0x1c3e0;
*(uint64_t*)0x200013a0 = 0;
*(uint64_t*)0x200013a8 = 0;
*(uint64_t*)0x200013b0 = 0x1c5e0;
*(uint64_t*)0x200013b8 = 0;
*(uint64_t*)0x200013c0 = 0;
*(uint64_t*)0x200013c8 = 0x1c7e0;
*(uint64_t*)0x200013d0 = 0;
*(uint64_t*)0x200013d8 = 0;
*(uint64_t*)0x200013e0 = 0x1c9e0;
*(uint64_t*)0x200013e8 = 0;
*(uint64_t*)0x200013f0 = 0;
*(uint64_t*)0x200013f8 = 0x1cbe0;
*(uint64_t*)0x20001400 = 0;
*(uint64_t*)0x20001408 = 0;
*(uint64_t*)0x20001410 = 0x1cde0;
*(uint64_t*)0x20001418 = 0;
*(uint64_t*)0x20001420 = 0;
*(uint64_t*)0x20001428 = 0x1cfe0;
*(uint64_t*)0x20001430 = 0;
*(uint64_t*)0x20001438 = 0;
*(uint64_t*)0x20001440 = 0x1d1e0;
*(uint64_t*)0x20001448 = 0;
*(uint64_t*)0x20001450 = 0;
*(uint64_t*)0x20001458 = 0x1d3e0;
*(uint64_t*)0x20001460 = 0;
*(uint64_t*)0x20001468 = 0;
*(uint64_t*)0x20001470 = 0x1d5e0;
*(uint64_t*)0x20001478 = 0;
*(uint64_t*)0x20001480 = 0;
*(uint64_t*)0x20001488 = 0x1d7e0;
*(uint64_t*)0x20001490 = 0;
*(uint64_t*)0x20001498 = 0;
*(uint64_t*)0x200014a0 = 0x1d9e0;
*(uint64_t*)0x200014a8 = 0;
*(uint64_t*)0x200014b0 = 0;
*(uint64_t*)0x200014b8 = 0x1dbe0;
*(uint64_t*)0x200014c0 = 0;
*(uint64_t*)0x200014c8 = 0;
*(uint64_t*)0x200014d0 = 0x1dde0;
*(uint64_t*)0x200014d8 = 0;
*(uint64_t*)0x200014e0 = 0;
*(uint64_t*)0x200014e8 = 0x1dfe0;
*(uint64_t*)0x200014f0 = 0;
*(uint64_t*)0x200014f8 = 0;
*(uint64_t*)0x20001500 = 0x1e1e0;
*(uint64_t*)0x20001508 = 0;
*(uint64_t*)0x20001510 = 0;
*(uint64_t*)0x20001518 = 0x1e3e0;
*(uint64_t*)0x20001520 = 0;
*(uint64_t*)0x20001528 = 0;
*(uint64_t*)0x20001530 = 0x1e5e0;
*(uint64_t*)0x20001538 = 0;
*(uint64_t*)0x20001540 = 0;
*(uint64_t*)0x20001548 = 0x1e7e0;
*(uint64_t*)0x20001550 = 0;
*(uint64_t*)0x20001558 = 0;
*(uint64_t*)0x20001560 = 0x1e9e0;
*(uint64_t*)0x20001568 = 0;
*(uint64_t*)0x20001570 = 0;
*(uint64_t*)0x20001578 = 0x1ebe0;
*(uint64_t*)0x20001580 = 0;
*(uint64_t*)0x20001588 = 0;
*(uint64_t*)0x20001590 = 0x1ede0;
*(uint64_t*)0x20001598 = 0;
*(uint64_t*)0x200015a0 = 0;
*(uint64_t*)0x200015a8 = 0x1efe0;
*(uint64_t*)0x200015b0 = 0;
*(uint64_t*)0x200015b8 = 0;
*(uint64_t*)0x200015c0 = 0x1f1e0;
*(uint64_t*)0x200015c8 = 0;
*(uint64_t*)0x200015d0 = 0;
*(uint64_t*)0x200015d8 = 0x1f3e0;
*(uint64_t*)0x200015e0 = 0;
*(uint64_t*)0x200015e8 = 0;
*(uint64_t*)0x200015f0 = 0x1f5e0;
*(uint64_t*)0x200015f8 = 0;
*(uint64_t*)0x20001600 = 0;
*(uint64_t*)0x20001608 = 0x1f7e0;
*(uint64_t*)0x20001610 = 0;
*(uint64_t*)0x20001618 = 0;
*(uint64_t*)0x20001620 = 0x1f9e0;
*(uint64_t*)0x20001628 = 0;
*(uint64_t*)0x20001630 = 0;
*(uint64_t*)0x20001638 = 0x1fbe0;
*(uint64_t*)0x20001640 = 0;
*(uint64_t*)0x20001648 = 0;
*(uint64_t*)0x20001650 = 0x1fde0;
*(uint64_t*)0x20001658 = 0;
*(uint64_t*)0x20001660 = 0;
*(uint64_t*)0x20001668 = 0x1ffe0;
*(uint64_t*)0x20001670 = 0;
*(uint64_t*)0x20001678 = 0;
*(uint64_t*)0x20001680 = 0x201e0;
*(uint64_t*)0x20001688 = 0;
*(uint64_t*)0x20001690 = 0;
*(uint64_t*)0x20001698 = 0x203e0;
*(uint64_t*)0x200016a0 = 0;
*(uint64_t*)0x200016a8 = 0;
*(uint64_t*)0x200016b0 = 0x205e0;
*(uint64_t*)0x200016b8 = 0;
*(uint64_t*)0x200016c0 = 0;
*(uint64_t*)0x200016c8 = 0x207e0;
*(uint64_t*)0x200016d0 = 0;
*(uint64_t*)0x200016d8 = 0;
*(uint64_t*)0x200016e0 = 0x209e0;
*(uint64_t*)0x200016e8 = 0;
*(uint64_t*)0x200016f0 = 0;
*(uint64_t*)0x200016f8 = 0x20be0;
*(uint64_t*)0x20001700 = 0;
*(uint64_t*)0x20001708 = 0;
*(uint64_t*)0x20001710 = 0x20de0;
*(uint64_t*)0x20001718 = 0;
*(uint64_t*)0x20001720 = 0;
*(uint64_t*)0x20001728 = 0x20fe0;
*(uint64_t*)0x20001730 = 0;
*(uint64_t*)0x20001738 = 0;
*(uint64_t*)0x20001740 = 0x211e0;
*(uint64_t*)0x20001748 = 0;
*(uint64_t*)0x20001750 = 0;
*(uint64_t*)0x20001758 = 0x213e0;
*(uint64_t*)0x20001760 = 0;
*(uint64_t*)0x20001768 = 0;
*(uint64_t*)0x20001770 = 0x215e0;
*(uint64_t*)0x20001778 = 0;
*(uint64_t*)0x20001780 = 0;
*(uint64_t*)0x20001788 = 0x217e0;
*(uint64_t*)0x20001790 = 0;
*(uint64_t*)0x20001798 = 0;
*(uint64_t*)0x200017a0 = 0x219e0;
*(uint64_t*)0x200017a8 = 0;
*(uint64_t*)0x200017b0 = 0;
*(uint64_t*)0x200017b8 = 0x21be0;
*(uint64_t*)0x200017c0 = 0;
*(uint64_t*)0x200017c8 = 0;
*(uint64_t*)0x200017d0 = 0x21de0;
*(uint64_t*)0x200017d8 = 0;
*(uint64_t*)0x200017e0 = 0;
*(uint64_t*)0x200017e8 = 0x21fe0;
*(uint64_t*)0x200017f0 = 0;
*(uint64_t*)0x200017f8 = 0;
*(uint64_t*)0x20001800 = 0x221e0;
*(uint64_t*)0x20001808 = 0;
*(uint64_t*)0x20001810 = 0;
*(uint64_t*)0x20001818 = 0x223e0;
*(uint64_t*)0x20001820 = 0;
*(uint64_t*)0x20001828 = 0;
*(uint64_t*)0x20001830 = 0x225e0;
*(uint64_t*)0x20001838 = 0;
*(uint64_t*)0x20001840 = 0;
*(uint64_t*)0x20001848 = 0x227e0;
*(uint64_t*)0x20001850 = 0;
*(uint64_t*)0x20001858 = 0;
*(uint64_t*)0x20001860 = 0x229e0;
*(uint64_t*)0x20001868 = 0;
*(uint64_t*)0x20001870 = 0;
*(uint64_t*)0x20001878 = 0x22be0;
*(uint64_t*)0x20001880 = 0;
*(uint64_t*)0x20001888 = 0;
*(uint64_t*)0x20001890 = 0x22de0;
*(uint64_t*)0x20001898 = 0x20016900;
*(uint64_t*)0x200018a0 = 0;
*(uint64_t*)0x200018a8 = 0x22fe0;
*(uint64_t*)0x200018b0 = 0;
*(uint64_t*)0x200018b8 = 0;
*(uint64_t*)0x200018c0 = 0x231e0;
*(uint64_t*)0x200018c8 = 0;
*(uint64_t*)0x200018d0 = 0;
*(uint64_t*)0x200018d8 = 0x233e0;
*(uint64_t*)0x200018e0 = 0;
*(uint64_t*)0x200018e8 = 0;
*(uint64_t*)0x200018f0 = 0x235e0;
*(uint64_t*)0x200018f8 = 0;
*(uint64_t*)0x20001900 = 0;
*(uint64_t*)0x20001908 = 0x237e0;
*(uint64_t*)0x20001910 = 0;
*(uint64_t*)0x20001918 = 0;
*(uint64_t*)0x20001920 = 0x239e0;
*(uint64_t*)0x20001928 = 0;
*(uint64_t*)0x20001930 = 0;
*(uint64_t*)0x20001938 = 0x23be0;
*(uint64_t*)0x20001940 = 0;
*(uint64_t*)0x20001948 = 0;
*(uint64_t*)0x20001950 = 0x23de0;
*(uint64_t*)0x20001958 = 0;
*(uint64_t*)0x20001960 = 0;
*(uint64_t*)0x20001968 = 0x23fe0;
*(uint64_t*)0x20001970 = 0;
*(uint64_t*)0x20001978 = 0;
*(uint64_t*)0x20001980 = 0x241e0;
*(uint64_t*)0x20001988 = 0;
*(uint64_t*)0x20001990 = 0;
*(uint64_t*)0x20001998 = 0x243e0;
*(uint64_t*)0x200019a0 = 0;
*(uint64_t*)0x200019a8 = 0;
*(uint64_t*)0x200019b0 = 0x245e0;
*(uint64_t*)0x200019b8 = 0;
*(uint64_t*)0x200019c0 = 0;
*(uint64_t*)0x200019c8 = 0x247e0;
*(uint64_t*)0x200019d0 = 0;
*(uint64_t*)0x200019d8 = 0;
*(uint64_t*)0x200019e0 = 0x249e0;
*(uint64_t*)0x200019e8 = 0;
*(uint64_t*)0x200019f0 = 0;
*(uint64_t*)0x200019f8 = 0x24be0;
*(uint64_t*)0x20001a00 = 0;
*(uint64_t*)0x20001a08 = 0;
*(uint64_t*)0x20001a10 = 0x24de0;
*(uint64_t*)0x20001a18 = 0;
*(uint64_t*)0x20001a20 = 0;
*(uint64_t*)0x20001a28 = 0x24fe0;
*(uint64_t*)0x20001a30 = 0;
*(uint64_t*)0x20001a38 = 0;
*(uint64_t*)0x20001a40 = 0x251e0;
*(uint64_t*)0x20001a48 = 0;
*(uint64_t*)0x20001a50 = 0;
*(uint64_t*)0x20001a58 = 0x253e0;
*(uint64_t*)0x20001a60 = 0;
*(uint64_t*)0x20001a68 = 0;
*(uint64_t*)0x20001a70 = 0x255e0;
*(uint64_t*)0x20001a78 = 0;
*(uint64_t*)0x20001a80 = 0;
*(uint64_t*)0x20001a88 = 0x257e0;
*(uint64_t*)0x20001a90 = 0;
*(uint64_t*)0x20001a98 = 0;
*(uint64_t*)0x20001aa0 = 0x259e0;
*(uint64_t*)0x20001aa8 = 0;
*(uint64_t*)0x20001ab0 = 0;
*(uint64_t*)0x20001ab8 = 0x25be0;
*(uint64_t*)0x20001ac0 = 0;
*(uint64_t*)0x20001ac8 = 0;
*(uint64_t*)0x20001ad0 = 0x25de0;
*(uint64_t*)0x20001ad8 = 0;
*(uint64_t*)0x20001ae0 = 0;
*(uint64_t*)0x20001ae8 = 0x25fe0;
*(uint64_t*)0x20001af0 = 0;
*(uint64_t*)0x20001af8 = 0;
*(uint64_t*)0x20001b00 = 0x261e0;
*(uint64_t*)0x20001b08 = 0;
*(uint64_t*)0x20001b10 = 0;
*(uint64_t*)0x20001b18 = 0x263e0;
*(uint64_t*)0x20001b20 = 0;
*(uint64_t*)0x20001b28 = 0;
*(uint64_t*)0x20001b30 = 0x265e0;
*(uint64_t*)0x20001b38 = 0;
*(uint64_t*)0x20001b40 = 0;
*(uint64_t*)0x20001b48 = 0x267e0;
*(uint64_t*)0x20001b50 = 0;
*(uint64_t*)0x20001b58 = 0;
*(uint64_t*)0x20001b60 = 0x269e0;
*(uint64_t*)0x20001b68 = 0;
*(uint64_t*)0x20001b70 = 0;
*(uint64_t*)0x20001b78 = 0x26be0;
*(uint64_t*)0x20001b80 = 0;
*(uint64_t*)0x20001b88 = 0;
*(uint64_t*)0x20001b90 = 0x26de0;
*(uint64_t*)0x20001b98 = 0;
*(uint64_t*)0x20001ba0 = 0;
*(uint64_t*)0x20001ba8 = 0x26fe0;
*(uint64_t*)0x20001bb0 = 0;
*(uint64_t*)0x20001bb8 = 0;
*(uint64_t*)0x20001bc0 = 0x271e0;
*(uint64_t*)0x20001bc8 = 0;
*(uint64_t*)0x20001bd0 = 0;
*(uint64_t*)0x20001bd8 = 0x273e0;
*(uint64_t*)0x20001be0 = 0;
*(uint64_t*)0x20001be8 = 0;
*(uint64_t*)0x20001bf0 = 0x275e0;
*(uint64_t*)0x20001bf8 = 0;
*(uint64_t*)0x20001c00 = 0;
*(uint64_t*)0x20001c08 = 0x277e0;
*(uint64_t*)0x20001c10 = 0;
*(uint64_t*)0x20001c18 = 0;
*(uint64_t*)0x20001c20 = 0x279e0;
*(uint64_t*)0x20001c28 = 0;
*(uint64_t*)0x20001c30 = 0;
*(uint64_t*)0x20001c38 = 0x27be0;
*(uint64_t*)0x20001c40 = 0;
*(uint64_t*)0x20001c48 = 0;
*(uint64_t*)0x20001c50 = 0x27de0;
*(uint64_t*)0x20001c58 = 0;
*(uint64_t*)0x20001c60 = 0;
*(uint64_t*)0x20001c68 = 0x27fe0;
*(uint64_t*)0x20001c70 = 0;
*(uint64_t*)0x20001c78 = 0;
*(uint64_t*)0x20001c80 = 0x281e0;
*(uint64_t*)0x20001c88 = 0;
*(uint64_t*)0x20001c90 = 0;
*(uint64_t*)0x20001c98 = 0x283e0;
*(uint64_t*)0x20001ca0 = 0;
*(uint64_t*)0x20001ca8 = 0;
*(uint64_t*)0x20001cb0 = 0x285e0;
*(uint64_t*)0x20001cb8 = 0;
*(uint64_t*)0x20001cc0 = 0;
*(uint64_t*)0x20001cc8 = 0x287e0;
*(uint64_t*)0x20001cd0 = 0;
*(uint64_t*)0x20001cd8 = 0;
*(uint64_t*)0x20001ce0 = 0x289e0;
*(uint64_t*)0x20001ce8 = 0;
*(uint64_t*)0x20001cf0 = 0;
*(uint64_t*)0x20001cf8 = 0x28be0;
*(uint64_t*)0x20001d00 = 0;
*(uint64_t*)0x20001d08 = 0;
*(uint64_t*)0x20001d10 = 0x28de0;
*(uint64_t*)0x20001d18 = 0;
*(uint64_t*)0x20001d20 = 0;
*(uint64_t*)0x20001d28 = 0x28fe0;
*(uint64_t*)0x20001d30 = 0;
*(uint64_t*)0x20001d38 = 0;
*(uint64_t*)0x20001d40 = 0x291e0;
*(uint64_t*)0x20001d48 = 0;
*(uint64_t*)0x20001d50 = 0;
*(uint64_t*)0x20001d58 = 0x293e0;
*(uint64_t*)0x20001d60 = 0;
*(uint64_t*)0x20001d68 = 0;
*(uint64_t*)0x20001d70 = 0x295e0;
*(uint64_t*)0x20001d78 = 0;
*(uint64_t*)0x20001d80 = 0;
*(uint64_t*)0x20001d88 = 0x297e0;
*(uint64_t*)0x20001d90 = 0;
*(uint64_t*)0x20001d98 = 0;
*(uint64_t*)0x20001da0 = 0x299e0;
*(uint64_t*)0x20001da8 = 0;
*(uint64_t*)0x20001db0 = 0;
*(uint64_t*)0x20001db8 = 0x29be0;
*(uint64_t*)0x20001dc0 = 0x200176e0;
*(uint64_t*)0x20001dc8 = 0;
*(uint64_t*)0x20001dd0 = 0x29de0;
*(uint64_t*)0x20001dd8 = 0;
*(uint64_t*)0x20001de0 = 0;
*(uint64_t*)0x20001de8 = 0x29fe0;
*(uint64_t*)0x20001df0 = 0;
*(uint64_t*)0x20001df8 = 0;
*(uint64_t*)0x20001e00 = 0x2a1e0;
*(uint64_t*)0x20001e08 = 0;
*(uint64_t*)0x20001e10 = 0;
*(uint64_t*)0x20001e18 = 0x2a3e0;
*(uint64_t*)0x20001e20 = 0;
*(uint64_t*)0x20001e28 = 0;
*(uint64_t*)0x20001e30 = 0x2a5e0;
*(uint64_t*)0x20001e38 = 0;
*(uint64_t*)0x20001e40 = 0;
*(uint64_t*)0x20001e48 = 0x2a7e0;
*(uint64_t*)0x20001e50 = 0;
*(uint64_t*)0x20001e58 = 0;
*(uint64_t*)0x20001e60 = 0x2a9e0;
*(uint64_t*)0x20001e68 = 0;
*(uint64_t*)0x20001e70 = 0;
*(uint64_t*)0x20001e78 = 0x2abe0;
*(uint64_t*)0x20001e80 = 0;
*(uint64_t*)0x20001e88 = 0;
*(uint64_t*)0x20001e90 = 0x2ade0;
*(uint64_t*)0x20001e98 = 0;
*(uint64_t*)0x20001ea0 = 0;
*(uint64_t*)0x20001ea8 = 0x2afe0;
*(uint64_t*)0x20001eb0 = 0;
*(uint64_t*)0x20001eb8 = 0;
*(uint64_t*)0x20001ec0 = 0x2b1e0;
*(uint64_t*)0x20001ec8 = 0;
*(uint64_t*)0x20001ed0 = 0;
*(uint64_t*)0x20001ed8 = 0x2b3e0;
*(uint64_t*)0x20001ee0 = 0;
*(uint64_t*)0x20001ee8 = 0;
*(uint64_t*)0x20001ef0 = 0x2b5e0;
*(uint64_t*)0x20001ef8 = 0;
*(uint64_t*)0x20001f00 = 0;
*(uint64_t*)0x20001f08 = 0x2b7e0;
*(uint64_t*)0x20001f10 = 0;
*(uint64_t*)0x20001f18 = 0;
*(uint64_t*)0x20001f20 = 0x2b9e0;
*(uint64_t*)0x20001f28 = 0;
*(uint64_t*)0x20001f30 = 0;
*(uint64_t*)0x20001f38 = 0x2bbe0;
*(uint64_t*)0x20001f40 = 0;
*(uint64_t*)0x20001f48 = 0;
*(uint64_t*)0x20001f50 = 0x2bde0;
*(uint64_t*)0x20001f58 = 0;
*(uint64_t*)0x20001f60 = 0;
*(uint64_t*)0x20001f68 = 0x2bfe0;
*(uint64_t*)0x20001f70 = 0;
*(uint64_t*)0x20001f78 = 0;
*(uint64_t*)0x20001f80 = 0x2c1e0;
*(uint64_t*)0x20001f88 = 0;
*(uint64_t*)0x20001f90 = 0;
*(uint64_t*)0x20001f98 = 0x2c3e0;
*(uint64_t*)0x20001fa0 = 0;
*(uint64_t*)0x20001fa8 = 0;
*(uint64_t*)0x20001fb0 = 0x2c5e0;
*(uint64_t*)0x20001fb8 = 0;
*(uint64_t*)0x20001fc0 = 0;
*(uint64_t*)0x20001fc8 = 0x2c7e0;
*(uint64_t*)0x20001fd0 = 0;
*(uint64_t*)0x20001fd8 = 0;
*(uint64_t*)0x20001fe0 = 0x2c9e0;
*(uint64_t*)0x20001fe8 = 0;
*(uint64_t*)0x20001ff0 = 0;
*(uint64_t*)0x20001ff8 = 0x2cbe0;
*(uint64_t*)0x20002000 = 0;
*(uint64_t*)0x20002008 = 0;
*(uint64_t*)0x20002010 = 0x2cde0;
*(uint64_t*)0x20002018 = 0;
*(uint64_t*)0x20002020 = 0;
*(uint64_t*)0x20002028 = 0x2cfe0;
*(uint64_t*)0x20002030 = 0;
*(uint64_t*)0x20002038 = 0;
*(uint64_t*)0x20002040 = 0x2d1e0;
*(uint64_t*)0x20002048 = 0;
*(uint64_t*)0x20002050 = 0;
*(uint64_t*)0x20002058 = 0x2d3e0;
*(uint64_t*)0x20002060 = 0;
*(uint64_t*)0x20002068 = 0;
*(uint64_t*)0x20002070 = 0x2d5e0;
*(uint64_t*)0x20002078 = 0;
*(uint64_t*)0x20002080 = 0;
*(uint64_t*)0x20002088 = 0x2d7e0;
*(uint64_t*)0x20002090 = 0;
*(uint64_t*)0x20002098 = 0;
*(uint64_t*)0x200020a0 = 0x2d9e0;
*(uint64_t*)0x200020a8 = 0;
*(uint64_t*)0x200020b0 = 0;
*(uint64_t*)0x200020b8 = 0x2dbe0;
*(uint64_t*)0x200020c0 = 0;
*(uint64_t*)0x200020c8 = 0;
*(uint64_t*)0x200020d0 = 0x2dde0;
*(uint64_t*)0x200020d8 = 0;
*(uint64_t*)0x200020e0 = 0;
*(uint64_t*)0x200020e8 = 0x2dfe0;
*(uint64_t*)0x200020f0 = 0;
*(uint64_t*)0x200020f8 = 0;
*(uint64_t*)0x20002100 = 0x2e1e0;
*(uint64_t*)0x20002108 = 0;
*(uint64_t*)0x20002110 = 0;
*(uint64_t*)0x20002118 = 0x2e3e0;
*(uint64_t*)0x20002120 = 0;
*(uint64_t*)0x20002128 = 0;
*(uint64_t*)0x20002130 = 0x2e5e0;
*(uint64_t*)0x20002138 = 0;
*(uint64_t*)0x20002140 = 0;
*(uint64_t*)0x20002148 = 0x2e7e0;
*(uint64_t*)0x20002150 = 0;
*(uint64_t*)0x20002158 = 0;
*(uint64_t*)0x20002160 = 0x2e9e0;
*(uint64_t*)0x20002168 = 0;
*(uint64_t*)0x20002170 = 0;
*(uint64_t*)0x20002178 = 0x2ebe0;
*(uint64_t*)0x20002180 = 0;
*(uint64_t*)0x20002188 = 0;
*(uint64_t*)0x20002190 = 0x2ede0;
*(uint64_t*)0x20002198 = 0;
*(uint64_t*)0x200021a0 = 0;
*(uint64_t*)0x200021a8 = 0x2efe0;
*(uint64_t*)0x200021b0 = 0;
*(uint64_t*)0x200021b8 = 0;
*(uint64_t*)0x200021c0 = 0x2f1e0;
*(uint64_t*)0x200021c8 = 0;
*(uint64_t*)0x200021d0 = 0;
*(uint64_t*)0x200021d8 = 0x2f3e0;
*(uint64_t*)0x200021e0 = 0;
*(uint64_t*)0x200021e8 = 0;
*(uint64_t*)0x200021f0 = 0x2f5e0;
*(uint64_t*)0x200021f8 = 0;
*(uint64_t*)0x20002200 = 0;
*(uint64_t*)0x20002208 = 0x2f7e0;
*(uint64_t*)0x20002210 = 0;
*(uint64_t*)0x20002218 = 0;
*(uint64_t*)0x20002220 = 0x2f9e0;
*(uint64_t*)0x20002228 = 0;
*(uint64_t*)0x20002230 = 0;
*(uint64_t*)0x20002238 = 0x2fbe0;
*(uint64_t*)0x20002240 = 0;
*(uint64_t*)0x20002248 = 0;
*(uint64_t*)0x20002250 = 0x2fde0;
*(uint64_t*)0x20002258 = 0;
*(uint64_t*)0x20002260 = 0;
*(uint64_t*)0x20002268 = 0x2ffe0;
*(uint64_t*)0x20002270 = 0;
*(uint64_t*)0x20002278 = 0;
*(uint64_t*)0x20002280 = 0x301e0;
*(uint64_t*)0x20002288 = 0;
*(uint64_t*)0x20002290 = 0;
*(uint64_t*)0x20002298 = 0x303e0;
*(uint64_t*)0x200022a0 = 0;
*(uint64_t*)0x200022a8 = 0;
*(uint64_t*)0x200022b0 = 0x305e0;
*(uint64_t*)0x200022b8 = 0;
*(uint64_t*)0x200022c0 = 0;
*(uint64_t*)0x200022c8 = 0x307e0;
*(uint64_t*)0x200022d0 = 0;
*(uint64_t*)0x200022d8 = 0;
*(uint64_t*)0x200022e0 = 0x309e0;
*(uint64_t*)0x200022e8 = 0;
*(uint64_t*)0x200022f0 = 0;
*(uint64_t*)0x200022f8 = 0x30be0;
*(uint64_t*)0x20002300 = 0;
*(uint64_t*)0x20002308 = 0;
*(uint64_t*)0x20002310 = 0x30de0;
*(uint64_t*)0x20002318 = 0;
*(uint64_t*)0x20002320 = 0;
*(uint64_t*)0x20002328 = 0x30fe0;
*(uint64_t*)0x20002330 = 0;
*(uint64_t*)0x20002338 = 0;
*(uint64_t*)0x20002340 = 0x311e0;
*(uint64_t*)0x20002348 = 0;
*(uint64_t*)0x20002350 = 0;
*(uint64_t*)0x20002358 = 0x313e0;
*(uint64_t*)0x20002360 = 0;
*(uint64_t*)0x20002368 = 0;
*(uint64_t*)0x20002370 = 0x315e0;
*(uint64_t*)0x20002378 = 0;
*(uint64_t*)0x20002380 = 0;
*(uint64_t*)0x20002388 = 0x317e0;
*(uint64_t*)0x20002390 = 0;
*(uint64_t*)0x20002398 = 0;
*(uint64_t*)0x200023a0 = 0x319e0;
*(uint64_t*)0x200023a8 = 0;
*(uint64_t*)0x200023b0 = 0;
*(uint64_t*)0x200023b8 = 0x31be0;
*(uint64_t*)0x200023c0 = 0;
*(uint64_t*)0x200023c8 = 0;
*(uint64_t*)0x200023d0 = 0x31de0;
*(uint64_t*)0x200023d8 = 0;
*(uint64_t*)0x200023e0 = 0;
*(uint64_t*)0x200023e8 = 0x31fe0;
*(uint64_t*)0x200023f0 = 0;
*(uint64_t*)0x200023f8 = 0;
*(uint64_t*)0x20002400 = 0x321e0;
*(uint64_t*)0x20002408 = 0;
*(uint64_t*)0x20002410 = 0;
*(uint64_t*)0x20002418 = 0x323e0;
*(uint64_t*)0x20002420 = 0;
*(uint64_t*)0x20002428 = 0;
*(uint64_t*)0x20002430 = 0x325e0;
*(uint64_t*)0x20002438 = 0;
*(uint64_t*)0x20002440 = 0;
*(uint64_t*)0x20002448 = 0x327e0;
*(uint64_t*)0x20002450 = 0;
*(uint64_t*)0x20002458 = 0;
*(uint64_t*)0x20002460 = 0x329e0;
*(uint64_t*)0x20002468 = 0;
*(uint64_t*)0x20002470 = 0;
*(uint64_t*)0x20002478 = 0x32be0;
*(uint64_t*)0x20002480 = 0;
*(uint64_t*)0x20002488 = 0;
*(uint64_t*)0x20002490 = 0x32de0;
*(uint64_t*)0x20002498 = 0;
*(uint64_t*)0x200024a0 = 0;
*(uint64_t*)0x200024a8 = 0x32fe0;
*(uint64_t*)0x200024b0 = 0;
*(uint64_t*)0x200024b8 = 0;
*(uint64_t*)0x200024c0 = 0x331e0;
*(uint64_t*)0x200024c8 = 0;
*(uint64_t*)0x200024d0 = 0;
*(uint64_t*)0x200024d8 = 0x333e0;
*(uint64_t*)0x200024e0 = 0;
*(uint64_t*)0x200024e8 = 0;
*(uint64_t*)0x200024f0 = 0x335e0;
*(uint64_t*)0x200024f8 = 0;
*(uint64_t*)0x20002500 = 0;
*(uint64_t*)0x20002508 = 0x337e0;
*(uint64_t*)0x20002510 = 0;
*(uint64_t*)0x20002518 = 0;
*(uint64_t*)0x20002520 = 0x339e0;
*(uint64_t*)0x20002528 = 0;
*(uint64_t*)0x20002530 = 0;
*(uint64_t*)0x20002538 = 0x33be0;
*(uint64_t*)0x20002540 = 0;
*(uint64_t*)0x20002548 = 0;
*(uint64_t*)0x20002550 = 0x33de0;
*(uint64_t*)0x20002558 = 0;
*(uint64_t*)0x20002560 = 0;
*(uint64_t*)0x20002568 = 0x33fe0;
*(uint64_t*)0x20002570 = 0;
*(uint64_t*)0x20002578 = 0;
*(uint64_t*)0x20002580 = 0x341e0;
*(uint64_t*)0x20002588 = 0;
*(uint64_t*)0x20002590 = 0;
*(uint64_t*)0x20002598 = 0x343e0;
*(uint64_t*)0x200025a0 = 0;
*(uint64_t*)0x200025a8 = 0;
*(uint64_t*)0x200025b0 = 0x345e0;
*(uint64_t*)0x200025b8 = 0;
*(uint64_t*)0x200025c0 = 0;
*(uint64_t*)0x200025c8 = 0x347e0;
*(uint64_t*)0x200025d0 = 0;
*(uint64_t*)0x200025d8 = 0;
*(uint64_t*)0x200025e0 = 0x349e0;
*(uint64_t*)0x200025e8 = 0;
*(uint64_t*)0x200025f0 = 0;
*(uint64_t*)0x200025f8 = 0x34be0;
*(uint64_t*)0x20002600 = 0;
*(uint64_t*)0x20002608 = 0;
*(uint64_t*)0x20002610 = 0x34de0;
*(uint64_t*)0x20002618 = 0;
*(uint64_t*)0x20002620 = 0;
*(uint64_t*)0x20002628 = 0x34fe0;
*(uint64_t*)0x20002630 = 0;
*(uint64_t*)0x20002638 = 0;
*(uint64_t*)0x20002640 = 0x351e0;
*(uint64_t*)0x20002648 = 0;
*(uint64_t*)0x20002650 = 0;
*(uint64_t*)0x20002658 = 0x353e0;
*(uint64_t*)0x20002660 = 0;
*(uint64_t*)0x20002668 = 0;
*(uint64_t*)0x20002670 = 0x355e0;
*(uint64_t*)0x20002678 = 0;
*(uint64_t*)0x20002680 = 0;
*(uint64_t*)0x20002688 = 0x357e0;
*(uint64_t*)0x20002690 = 0;
*(uint64_t*)0x20002698 = 0;
*(uint64_t*)0x200026a0 = 0x359e0;
*(uint64_t*)0x200026a8 = 0;
*(uint64_t*)0x200026b0 = 0;
*(uint64_t*)0x200026b8 = 0x35be0;
*(uint64_t*)0x200026c0 = 0;
*(uint64_t*)0x200026c8 = 0;
*(uint64_t*)0x200026d0 = 0x35de0;
*(uint64_t*)0x200026d8 = 0;
*(uint64_t*)0x200026e0 = 0;
*(uint64_t*)0x200026e8 = 0x35fe0;
*(uint64_t*)0x200026f0 = 0;
*(uint64_t*)0x200026f8 = 0;
*(uint64_t*)0x20002700 = 0x361e0;
*(uint64_t*)0x20002708 = 0;
*(uint64_t*)0x20002710 = 0;
*(uint64_t*)0x20002718 = 0x363e0;
*(uint64_t*)0x20002720 = 0;
*(uint64_t*)0x20002728 = 0;
*(uint64_t*)0x20002730 = 0x365e0;
*(uint64_t*)0x20002738 = 0;
*(uint64_t*)0x20002740 = 0;
*(uint64_t*)0x20002748 = 0x367e0;
*(uint64_t*)0x20002750 = 0;
*(uint64_t*)0x20002758 = 0;
*(uint64_t*)0x20002760 = 0x369e0;
*(uint64_t*)0x20002768 = 0;
*(uint64_t*)0x20002770 = 0;
*(uint64_t*)0x20002778 = 0x36be0;
*(uint64_t*)0x20002780 = 0;
*(uint64_t*)0x20002788 = 0;
*(uint64_t*)0x20002790 = 0x36de0;
*(uint64_t*)0x20002798 = 0;
*(uint64_t*)0x200027a0 = 0;
*(uint64_t*)0x200027a8 = 0x36fe0;
*(uint64_t*)0x200027b0 = 0;
*(uint64_t*)0x200027b8 = 0;
*(uint64_t*)0x200027c0 = 0x371e0;
*(uint64_t*)0x200027c8 = 0;
*(uint64_t*)0x200027d0 = 0;
*(uint64_t*)0x200027d8 = 0x373e0;
*(uint64_t*)0x200027e0 = 0;
*(uint64_t*)0x200027e8 = 0;
*(uint64_t*)0x200027f0 = 0x375e0;
*(uint64_t*)0x200027f8 = 0;
*(uint64_t*)0x20002800 = 0;
*(uint64_t*)0x20002808 = 0x377e0;
*(uint64_t*)0x20002810 = 0;
*(uint64_t*)0x20002818 = 0;
*(uint64_t*)0x20002820 = 0x379e0;
*(uint64_t*)0x20002828 = 0;
*(uint64_t*)0x20002830 = 0;
*(uint64_t*)0x20002838 = 0x37be0;
*(uint64_t*)0x20002840 = 0;
*(uint64_t*)0x20002848 = 0;
*(uint64_t*)0x20002850 = 0x37de0;
*(uint64_t*)0x20002858 = 0;
*(uint64_t*)0x20002860 = 0;
*(uint64_t*)0x20002868 = 0x37fe0;
*(uint64_t*)0x20002870 = 0;
*(uint64_t*)0x20002878 = 0;
*(uint64_t*)0x20002880 = 0x381e0;
*(uint64_t*)0x20002888 = 0;
*(uint64_t*)0x20002890 = 0;
*(uint64_t*)0x20002898 = 0x383e0;
*(uint64_t*)0x200028a0 = 0;
*(uint64_t*)0x200028a8 = 0;
*(uint64_t*)0x200028b0 = 0x385e0;
*(uint64_t*)0x200028b8 = 0;
*(uint64_t*)0x200028c0 = 0;
*(uint64_t*)0x200028c8 = 0x387e0;
*(uint64_t*)0x200028d0 = 0;
*(uint64_t*)0x200028d8 = 0;
*(uint64_t*)0x200028e0 = 0x389e0;
*(uint64_t*)0x200028e8 = 0;
*(uint64_t*)0x200028f0 = 0;
*(uint64_t*)0x200028f8 = 0x38be0;
*(uint64_t*)0x20002900 = 0;
*(uint64_t*)0x20002908 = 0;
*(uint64_t*)0x20002910 = 0x38de0;
*(uint64_t*)0x20002918 = 0;
*(uint64_t*)0x20002920 = 0;
*(uint64_t*)0x20002928 = 0x38fe0;
*(uint64_t*)0x20002930 = 0;
*(uint64_t*)0x20002938 = 0;
*(uint64_t*)0x20002940 = 0x391e0;
*(uint64_t*)0x20002948 = 0;
*(uint64_t*)0x20002950 = 0;
*(uint64_t*)0x20002958 = 0x393e0;
*(uint64_t*)0x20002960 = 0;
*(uint64_t*)0x20002968 = 0;
*(uint64_t*)0x20002970 = 0x395e0;
*(uint64_t*)0x20002978 = 0;
*(uint64_t*)0x20002980 = 0;
*(uint64_t*)0x20002988 = 0x397e0;
*(uint64_t*)0x20002990 = 0;
*(uint64_t*)0x20002998 = 0;
*(uint64_t*)0x200029a0 = 0x399e0;
*(uint64_t*)0x200029a8 = 0;
*(uint64_t*)0x200029b0 = 0;
*(uint64_t*)0x200029b8 = 0x39be0;
*(uint64_t*)0x200029c0 = 0;
*(uint64_t*)0x200029c8 = 0;
*(uint64_t*)0x200029d0 = 0x39de0;
*(uint64_t*)0x200029d8 = 0;
*(uint64_t*)0x200029e0 = 0;
*(uint64_t*)0x200029e8 = 0x39fe0;
*(uint64_t*)0x200029f0 = 0;
*(uint64_t*)0x200029f8 = 0;
*(uint64_t*)0x20002a00 = 0x3a1e0;
*(uint64_t*)0x20002a08 = 0;
*(uint64_t*)0x20002a10 = 0;
*(uint64_t*)0x20002a18 = 0x3a3e0;
*(uint64_t*)0x20002a20 = 0;
*(uint64_t*)0x20002a28 = 0;
*(uint64_t*)0x20002a30 = 0x3a5e0;
*(uint64_t*)0x20002a38 = 0;
*(uint64_t*)0x20002a40 = 0;
*(uint64_t*)0x20002a48 = 0x3a7e0;
*(uint64_t*)0x20002a50 = 0;
*(uint64_t*)0x20002a58 = 0;
*(uint64_t*)0x20002a60 = 0x3a9e0;
*(uint64_t*)0x20002a68 = 0;
*(uint64_t*)0x20002a70 = 0;
*(uint64_t*)0x20002a78 = 0x3abe0;
*(uint64_t*)0x20002a80 = 0;
*(uint64_t*)0x20002a88 = 0;
*(uint64_t*)0x20002a90 = 0x3ade0;
*(uint64_t*)0x20002a98 = 0;
*(uint64_t*)0x20002aa0 = 0;
*(uint64_t*)0x20002aa8 = 0x3afe0;
*(uint64_t*)0x20002ab0 = 0;
*(uint64_t*)0x20002ab8 = 0;
*(uint64_t*)0x20002ac0 = 0x3b1e0;
*(uint64_t*)0x20002ac8 = 0;
*(uint64_t*)0x20002ad0 = 0;
*(uint64_t*)0x20002ad8 = 0x3b3e0;
*(uint64_t*)0x20002ae0 = 0;
*(uint64_t*)0x20002ae8 = 0;
*(uint64_t*)0x20002af0 = 0x3b5e0;
*(uint64_t*)0x20002af8 = 0;
*(uint64_t*)0x20002b00 = 0;
*(uint64_t*)0x20002b08 = 0x3b7e0;
*(uint64_t*)0x20002b10 = 0;
*(uint64_t*)0x20002b18 = 0;
*(uint64_t*)0x20002b20 = 0x3b9e0;
*(uint64_t*)0x20002b28 = 0;
*(uint64_t*)0x20002b30 = 0;
*(uint64_t*)0x20002b38 = 0x3bbe0;
*(uint64_t*)0x20002b40 = 0;
*(uint64_t*)0x20002b48 = 0;
*(uint64_t*)0x20002b50 = 0x3bde0;
*(uint64_t*)0x20002b58 = 0;
*(uint64_t*)0x20002b60 = 0;
*(uint64_t*)0x20002b68 = 0x3bfe0;
*(uint64_t*)0x20002b70 = 0;
*(uint64_t*)0x20002b78 = 0;
*(uint64_t*)0x20002b80 = 0x3c1e0;
*(uint64_t*)0x20002b88 = 0;
*(uint64_t*)0x20002b90 = 0;
*(uint64_t*)0x20002b98 = 0x3c3e0;
*(uint64_t*)0x20002ba0 = 0;
*(uint64_t*)0x20002ba8 = 0;
*(uint64_t*)0x20002bb0 = 0x3c5e0;
*(uint64_t*)0x20002bb8 = 0;
*(uint64_t*)0x20002bc0 = 0;
*(uint64_t*)0x20002bc8 = 0x3c7e0;
*(uint64_t*)0x20002bd0 = 0;
*(uint64_t*)0x20002bd8 = 0;
*(uint64_t*)0x20002be0 = 0x3c9e0;
*(uint64_t*)0x20002be8 = 0;
*(uint64_t*)0x20002bf0 = 0;
*(uint64_t*)0x20002bf8 = 0x3cbe0;
*(uint64_t*)0x20002c00 = 0;
*(uint64_t*)0x20002c08 = 0;
*(uint64_t*)0x20002c10 = 0x3cde0;
*(uint64_t*)0x20002c18 = 0;
*(uint64_t*)0x20002c20 = 0;
*(uint64_t*)0x20002c28 = 0x3cfe0;
*(uint64_t*)0x20002c30 = 0;
*(uint64_t*)0x20002c38 = 0;
*(uint64_t*)0x20002c40 = 0x3d1e0;
*(uint64_t*)0x20002c48 = 0;
*(uint64_t*)0x20002c50 = 0;
*(uint64_t*)0x20002c58 = 0x3d3e0;
*(uint64_t*)0x20002c60 = 0;
*(uint64_t*)0x20002c68 = 0;
*(uint64_t*)0x20002c70 = 0x3d5e0;
*(uint64_t*)0x20002c78 = 0;
*(uint64_t*)0x20002c80 = 0;
*(uint64_t*)0x20002c88 = 0x3d7e0;
*(uint64_t*)0x20002c90 = 0;
*(uint64_t*)0x20002c98 = 0;
*(uint64_t*)0x20002ca0 = 0x3d9e0;
*(uint64_t*)0x20002ca8 = 0;
*(uint64_t*)0x20002cb0 = 0;
*(uint64_t*)0x20002cb8 = 0x3dbe0;
*(uint64_t*)0x20002cc0 = 0;
*(uint64_t*)0x20002cc8 = 0;
*(uint64_t*)0x20002cd0 = 0x3dde0;
*(uint64_t*)0x20002cd8 = 0;
*(uint64_t*)0x20002ce0 = 0;
*(uint64_t*)0x20002ce8 = 0x3dfe0;
*(uint64_t*)0x20002cf0 = 0;
*(uint64_t*)0x20002cf8 = 0;
*(uint64_t*)0x20002d00 = 0x3e1e0;
*(uint64_t*)0x20002d08 = 0;
*(uint64_t*)0x20002d10 = 0;
*(uint64_t*)0x20002d18 = 0x3e3e0;
*(uint64_t*)0x20002d20 = 0;
*(uint64_t*)0x20002d28 = 0;
*(uint64_t*)0x20002d30 = 0x3e5e0;
*(uint64_t*)0x20002d38 = 0;
*(uint64_t*)0x20002d40 = 0;
*(uint64_t*)0x20002d48 = 0x3e7e0;
*(uint64_t*)0x20002d50 = 0;
*(uint64_t*)0x20002d58 = 0;
*(uint64_t*)0x20002d60 = 0x3e9e0;
*(uint64_t*)0x20002d68 = 0;
*(uint64_t*)0x20002d70 = 0;
*(uint64_t*)0x20002d78 = 0x3ebe0;
*(uint64_t*)0x20002d80 = 0;
*(uint64_t*)0x20002d88 = 0;
*(uint64_t*)0x20002d90 = 0x3ede0;
*(uint64_t*)0x20002d98 = 0;
*(uint64_t*)0x20002da0 = 0;
*(uint64_t*)0x20002da8 = 0x3efe0;
*(uint64_t*)0x20002db0 = 0;
*(uint64_t*)0x20002db8 = 0;
*(uint64_t*)0x20002dc0 = 0x3f1e0;
*(uint64_t*)0x20002dc8 = 0;
*(uint64_t*)0x20002dd0 = 0;
*(uint64_t*)0x20002dd8 = 0x3f3e0;
*(uint64_t*)0x20002de0 = 0;
*(uint64_t*)0x20002de8 = 0;
*(uint64_t*)0x20002df0 = 0x3f5e0;
*(uint64_t*)0x20002df8 = 0;
*(uint64_t*)0x20002e00 = 0;
*(uint64_t*)0x20002e08 = 0x3f7e0;
*(uint64_t*)0x20002e10 = 0;
*(uint64_t*)0x20002e18 = 0;
*(uint64_t*)0x20002e20 = 0x3f9e0;
*(uint64_t*)0x20002e28 = 0;
*(uint64_t*)0x20002e30 = 0;
*(uint64_t*)0x20002e38 = 0x3fbe0;
*(uint64_t*)0x20002e40 = 0;
*(uint64_t*)0x20002e48 = 0;
*(uint64_t*)0x20002e50 = 0x3fde0;
*(uint64_t*)0x20002e58 = 0;
*(uint64_t*)0x20002e60 = 0;
*(uint64_t*)0x20002e68 = 0x3ffe0;
*(uint64_t*)0x20002e70 = 0;
*(uint64_t*)0x20002e78 = 0;
*(uint64_t*)0x20002e80 = 0x401e0;
*(uint64_t*)0x20002e88 = 0;
*(uint64_t*)0x20002e90 = 0;
*(uint64_t*)0x20002e98 = 0x403e0;
*(uint64_t*)0x20002ea0 = 0;
*(uint64_t*)0x20002ea8 = 0;
*(uint64_t*)0x20002eb0 = 0x405e0;
*(uint64_t*)0x20002eb8 = 0;
*(uint64_t*)0x20002ec0 = 0;
*(uint64_t*)0x20002ec8 = 0x407e0;
*(uint64_t*)0x20002ed0 = 0;
*(uint64_t*)0x20002ed8 = 0;
*(uint64_t*)0x20002ee0 = 0x409e0;
*(uint64_t*)0x20002ee8 = 0;
*(uint64_t*)0x20002ef0 = 0;
*(uint64_t*)0x20002ef8 = 0x40be0;
*(uint64_t*)0x20002f00 = 0;
*(uint64_t*)0x20002f08 = 0;
*(uint64_t*)0x20002f10 = 0x40de0;
*(uint64_t*)0x20002f18 = 0;
*(uint64_t*)0x20002f20 = 0;
*(uint64_t*)0x20002f28 = 0x40fe0;
*(uint64_t*)0x20002f30 = 0;
*(uint64_t*)0x20002f38 = 0;
*(uint64_t*)0x20002f40 = 0x411e0;
*(uint64_t*)0x20002f48 = 0;
*(uint64_t*)0x20002f50 = 0;
*(uint64_t*)0x20002f58 = 0x413e0;
*(uint64_t*)0x20002f60 = 0;
*(uint64_t*)0x20002f68 = 0;
*(uint64_t*)0x20002f70 = 0x415e0;
*(uint64_t*)0x20002f78 = 0;
*(uint64_t*)0x20002f80 = 0;
*(uint64_t*)0x20002f88 = 0x417e0;
*(uint64_t*)0x20002f90 = 0;
*(uint64_t*)0x20002f98 = 0;
*(uint64_t*)0x20002fa0 = 0x419e0;
*(uint64_t*)0x20002fa8 = 0;
*(uint64_t*)0x20002fb0 = 0;
*(uint64_t*)0x20002fb8 = 0x41be0;
*(uint64_t*)0x20002fc0 = 0;
*(uint64_t*)0x20002fc8 = 0;
*(uint64_t*)0x20002fd0 = 0x41de0;
*(uint64_t*)0x20002fd8 = 0;
*(uint64_t*)0x20002fe0 = 0;
*(uint64_t*)0x20002fe8 = 0x41fe0;
*(uint64_t*)0x20002ff0 = 0;
*(uint64_t*)0x20002ff8 = 0;
*(uint64_t*)0x20003000 = 0x421e0;
*(uint64_t*)0x20003008 = 0;
*(uint64_t*)0x20003010 = 0;
*(uint64_t*)0x20003018 = 0x423e0;
*(uint64_t*)0x20003020 = 0;
*(uint64_t*)0x20003028 = 0;
*(uint64_t*)0x20003030 = 0x425e0;
*(uint64_t*)0x20003038 = 0;
*(uint64_t*)0x20003040 = 0;
*(uint64_t*)0x20003048 = 0x427e0;
*(uint64_t*)0x20003050 = 0;
*(uint64_t*)0x20003058 = 0;
*(uint64_t*)0x20003060 = 0x429e0;
*(uint64_t*)0x20003068 = 0;
*(uint64_t*)0x20003070 = 0;
*(uint64_t*)0x20003078 = 0x42be0;
*(uint64_t*)0x20003080 = 0;
*(uint64_t*)0x20003088 = 0;
*(uint64_t*)0x20003090 = 0x42de0;
*(uint64_t*)0x20003098 = 0;
*(uint64_t*)0x200030a0 = 0;
*(uint64_t*)0x200030a8 = 0x42fe0;
*(uint64_t*)0x200030b0 = 0;
*(uint64_t*)0x200030b8 = 0;
*(uint64_t*)0x200030c0 = 0x44000;
*(uint64_t*)0x200030c8 = 0;
*(uint64_t*)0x200030d0 = 0;
*(uint64_t*)0x200030d8 = 0x45000;
*(uint64_t*)0x200030e0 = 0;
*(uint64_t*)0x200030e8 = 0;
*(uint64_t*)0x200030f0 = 0x457e0;
*(uint64_t*)0x200030f8 = 0;
*(uint64_t*)0x20003100 = 0;
*(uint64_t*)0x20003108 = 0x459e0;
*(uint64_t*)0x20003110 = 0;
*(uint64_t*)0x20003118 = 0;
*(uint64_t*)0x20003120 = 0x45be0;
*(uint64_t*)0x20003128 = 0;
*(uint64_t*)0x20003130 = 0;
*(uint64_t*)0x20003138 = 0x45de0;
*(uint64_t*)0x20003140 = 0;
*(uint64_t*)0x20003148 = 0;
*(uint64_t*)0x20003150 = 0x45fe0;
*(uint64_t*)0x20003158 = 0;
*(uint64_t*)0x20003160 = 0;
*(uint64_t*)0x20003168 = 0x46080;
*(uint64_t*)0x20003170 = 0;
*(uint64_t*)0x20003178 = 0;
*(uint64_t*)0x20003180 = 0x46120;
*(uint64_t*)0x20003188 = 0;
*(uint64_t*)0x20003190 = 0;
*(uint64_t*)0x20003198 = 0x461c0;
*(uint64_t*)0x200031a0 = 0;
*(uint64_t*)0x200031a8 = 0;
*(uint64_t*)0x200031b0 = 0x46260;
*(uint64_t*)0x200031b8 = 0;
*(uint64_t*)0x200031c0 = 0;
*(uint64_t*)0x200031c8 = 0x46300;
*(uint64_t*)0x200031d0 = 0;
*(uint64_t*)0x200031d8 = 0;
*(uint64_t*)0x200031e0 = 0x463a0;
*(uint64_t*)0x200031e8 = 0;
*(uint64_t*)0x200031f0 = 0;
*(uint64_t*)0x200031f8 = 0x46440;
*(uint64_t*)0x20003200 = 0;
*(uint64_t*)0x20003208 = 0;
*(uint64_t*)0x20003210 = 0x464e0;
*(uint64_t*)0x20003218 = 0;
*(uint64_t*)0x20003220 = 0;
*(uint64_t*)0x20003228 = 0x46580;
*(uint64_t*)0x20003230 = 0;
*(uint64_t*)0x20003238 = 0;
*(uint64_t*)0x20003240 = 0x46620;
*(uint64_t*)0x20003248 = 0;
*(uint64_t*)0x20003250 = 0;
*(uint64_t*)0x20003258 = 0x466c0;
*(uint64_t*)0x20003260 = 0;
*(uint64_t*)0x20003268 = 0;
*(uint64_t*)0x20003270 = 0x46760;
*(uint64_t*)0x20003278 = 0;
*(uint64_t*)0x20003280 = 0;
*(uint64_t*)0x20003288 = 0x46800;
*(uint64_t*)0x20003290 = 0;
*(uint64_t*)0x20003298 = 0;
*(uint64_t*)0x200032a0 = 0x468a0;
*(uint64_t*)0x200032a8 = 0;
*(uint64_t*)0x200032b0 = 0;
*(uint64_t*)0x200032b8 = 0x47000;
*(uint64_t*)0x200032c0 = 0;
*(uint64_t*)0x200032c8 = 0;
*(uint64_t*)0x200032d0 = 0x48000;
*(uint64_t*)0x200032d8 = 0;
*(uint64_t*)0x200032e0 = 0;
*(uint64_t*)0x200032e8 = 0x88000;
*(uint64_t*)0x200032f0 = 0;
*(uint64_t*)0x200032f8 = 0;
*(uint64_t*)0x20003300 = 0x89000;
*(uint64_t*)0x20003308 = 0;
*(uint64_t*)0x20003310 = 0;
*(uint64_t*)0x20003318 = 0;
*(uint64_t*)0x20003320 = 0;
*(uint64_t*)0x20003328 = 0;
*(uint64_t*)0x20003330 = 0xfffe0;
*(uint64_t*)0x20003338 = 0;
*(uint64_t*)0x20003340 = 0;
*(uint64_t*)0x20003348 = 0;
*(uint64_t*)0x20003350 = 0;
*(uint64_t*)0x20003358 = 0;
*(uint64_t*)0x20003360 = 0x1ffe00;
*(uint64_t*)0x20003368 = 0;
*(uint64_t*)0x20003370 = 0;
*(uint64_t*)0x20003378 = 0x1fffe0;
*(uint8_t*)0x2007c6a0 = 0;
syz_mount_image(0x20000000, 0x20000100, 0x200000, 0x210, 0x20000200, 0, 0x2007c6a0);
	syscall(__NR_getgid);
	syscall(__NR_setuid, 0);
	syscall(__NR_ioctl, -1, 0x80087601, 0ul);

}
int main(void)
{
		syscall(__NR_mmap, 0x1ffff000ul, 0x1000ul, 0ul, 0x32ul, -1, 0ul);
	syscall(__NR_mmap, 0x20000000ul, 0x1000000ul, 7ul, 0x32ul, -1, 0ul);
	syscall(__NR_mmap, 0x21000000ul, 0x1000ul, 0ul, 0x32ul, -1, 0ul);
			loop();
	return 0;
}
